@@ -38,6 +38,7 @@
 #include "media_perf_profiler.h"
 #include "frame_tracker.h"
 #include "media_common_defs.h"
+#include "surface_state_heap_mgr.h"
 
 class XRenderHal_Platform_Interface;
 
@@ -841,6 +842,7 @@ typedef struct _RENDERHAL_STATE_HEAP_SETTINGS
     int32_t             iSurfaceStates;                                         // Number of Surfaces per SSH
     int32_t             iSurfacesPerBT;                                         // Number of Surfaces per BT
     int32_t             iBTAlignment;                                           // BT Alignment size
+    MOS_HW_RESOURCE_DEF heapUsageType;
 } RENDERHAL_STATE_HEAP_SETTINGS, *PRENDERHAL_STATE_HEAP_SETTINGS;
 
 typedef struct _RENDERHAL_STATE_HEAP
@@ -965,7 +967,7 @@ typedef struct _RENDERHAL_STATE_HEAP
     RENDERHAL_KRN_ALLOC_LIST       KernelAllocationPool;                        // Pool of kernel allocation objects
     RENDERHAL_KRN_ALLOC_LIST       KernelsSubmitted;                            // Kernel submission list
     RENDERHAL_KRN_ALLOC_LIST       KernelsAllocated;                            // kernel allocation list (kernels in ISH not currently being executed)
-
+    SurfaceStateHeapManager       *surfaceStateMgr;                             // Surface state manager
 } RENDERHAL_STATE_HEAP, *PRENDERHAL_STATE_HEAP;
 
 typedef struct _RENDERHAL_DYNAMIC_MEDIA_STATE_PARAMS
@@ -1023,9 +1025,10 @@ typedef struct _RENDERHAL_SURFACE_STATE_PARAMS
     uint32_t                        bVmeUse                   : 1;              // Flag for VME use
     uint32_t                        bBufferUse                : 1;              // Flags for 1D buffer use
     uint32_t                        bSurfaceTypeDefined       : 1;
-    uint32_t                                                  : 2;
+    uint32_t                        forceCommonSurfaceMessage : 1;
     uint32_t                        surfaceType               : 11;
     MOS_COMPONENT                   Component                 : 4;
+    uint32_t                        reserved                  : 1;
     RENDERHAL_MEMORY_OBJECT_CONTROL MemObjCtl;                                  // Caching attributes
 } RENDERHAL_SURFACE_STATE_PARAMS, *PRENDERHAL_SURFACE_STATE_PARAMS;
 
@@ -1196,6 +1199,7 @@ typedef struct _RENDERHAL_INTERFACE
     bool                        bEnableGpgpuMidBatchPreEmption;                 // Middle Batch Buffer Preemption
     bool                        bEnableGpgpuMidThreadPreEmption;                // Middle Thread Preemption
     bool                        bComputeContextInUse;                           // Compute Context use for media
+    bool                        isBindlessHeapInUse;                            // Bindless Heap Mode use
 
     uint32_t                    dwMaskCrsThdConDataRdLn;                        // Unifies pfnSetupInterfaceDescriptor for g75,g8,...
     uint32_t                    dwMinNumberThreadsInGroup;                      // Unifies pfnSetupInterfaceDescriptor for g75,g8,...
@@ -1278,6 +1282,10 @@ typedef struct _RENDERHAL_INTERFACE
     MediaPerfProfiler           *pPerfProfiler = nullptr; //!< Performance data profiler
     bool                        eufusionBypass = false;
     MediaUserSettingSharedPtr   userSettingPtr = nullptr; //!< Shared pointer to User Setting instance
+
+    // if it's true, will disable preemption by setting NeedsMidBatchPreEmptionSupport flag in command buffer attribute as false;
+    // will also skip preemption control bits configure.
+    bool                        forceDisablePreemption = false;
     //---------------------------
     // HW interface functions
     //---------------------------
@@ -1368,6 +1376,13 @@ typedef struct _RENDERHAL_INTERFACE
                 PRENDERHAL_INTERFACE            pRenderHal,
                 int32_t                         *piBindingTable);
 
+    MOS_STATUS (* pfnAssignBindlessSurfaceStates) (
+                PRENDERHAL_INTERFACE            pRenderHal);
+
+    MOS_STATUS (*pfnSendBindlessSurfaceStates) (
+                PRENDERHAL_INTERFACE            pRenderHal,
+                bool                            bNeedNullPatch);
+
     MOS_STATUS (* pfnBindSurfaceState) (
                 PRENDERHAL_INTERFACE            pRenderHal,
                 int32_t                         iBindingTableIndex,
@@ -1378,6 +1393,12 @@ typedef struct _RENDERHAL_INTERFACE
                 PRENDERHAL_INTERFACE            pRenderHal,
                 PRENDERHAL_SURFACE_STATE_PARAMS pParams);
 
+    MOS_STATUS (*pfnGetPlaneDefinitionForCommonMessage) (
+                PRENDERHAL_INTERFACE            pRenderHal,
+                MOS_FORMAT                      format,
+                bool                            isRenderTarget,
+                RENDERHAL_PLANE_DEFINITION      &planeDefinition);
+
     //---------------------------
     // State Setup - HW + OS Specific
     //---------------------------
@@ -1453,6 +1474,13 @@ typedef struct _RENDERHAL_INTERFACE
                 PMHW_SAMPLER_STATE_PARAM    pSamplerParams,
                 int32_t                     iSamplers);
 
+    MOS_STATUS (*pfnSetAndGetSamplerStates) (
+                PRENDERHAL_INTERFACE     pRenderHal,
+                int32_t                  iMediaID,
+                PMHW_SAMPLER_STATE_PARAM pSamplerParams,
+                int32_t                  iSamplers,
+                std::map<uint32_t, uint32_t> &samplerMap);
+
     int32_t (* pfnAllocateMediaID) (
                 PRENDERHAL_INTERFACE        pRenderHal,
                 int32_t                     iKernelAllocationID,
