@@ -482,3 +482,13 @@ static bool dg2Gt4Device56C0 = DeviceInfoFactory<GfxDeviceInfo>::
 
 static bool dg2Gt4Device56C1 = DeviceInfoFactory<GfxDeviceInfo>::
     RegisterDevice(0x56C1, &dg2Gt4Info);
+
+static bool dg2Gt4Device56C2 = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x56C2, &dg2Gt4Info);
+
+static bool dg2Gt4Device56BE = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x56BE, &dg2Gt4Info);
+
+static bool dg2Gt4Device56BF = DeviceInfoFactory<GfxDeviceInfo>::
+    RegisterDevice(0x56BF, &dg2Gt4Info);
+
