@@ -140,6 +140,12 @@ public:
         case MHW_MMIO_CCS0_AUX_TABLE_INVALIDATE:
             mmioRegisters = M_MMIO_CCS0_AUX_TABLE_INVALIDATE;
             break;
+        case MHW_MMIO_BLT_AUX_TABLE_BASE_LOW:
+            mmioRegisters = M_MMIO_BLT_AUX_TABLE_BASE_LOW;
+            break;
+        case MHW_MMIO_BLT_AUX_TABLE_BASE_HIGH:
+            mmioRegisters = M_MMIO_BLT_AUX_TABLE_BASE_HIGH;
+            break;
         default:
             MHW_ASSERTMESSAGE("Invalid mmio data provided");;
             break;
@@ -324,22 +330,17 @@ public:
         }
         else
         {
-            if ((frameWidth * frameHeight) >= (16000 * 16000))
+            if ((frameWidth * frameHeight) >= (7680 * 4320))
             {
-                MediaResetParam.watchdogCountThreshold = MHW_MI_DECODER_16Kx16K_WATCHDOG_THRESHOLD_IN_MS;
+                MediaResetParam.watchdogCountThreshold = MHW_MI_DECODER_8K_WATCHDOG_THRESHOLD_IN_MS;
             }
-            else if ((frameWidth * frameHeight) >= (7680 * 4320))
+            else if ((frameWidth * frameHeight) >= (3840 * 2160))
             {
-                MediaResetParam.watchdogCountThreshold = MHW_MI_DECODER_16K_WATCHDOG_THRESHOLD_IN_MS;
-            }
-            else if (((frameWidth * frameHeight) < (1280 * 720)) && MEDIA_IS_WA(waTable, WaSliceMissingMB))
-            {
-                MediaResetParam.watchdogCountThreshold = MHW_MI_DECODER_720P_WATCHDOG_THRESHOLD_IN_MS;
+                MediaResetParam.watchdogCountThreshold = MHW_MI_DECODER_4K_WATCHDOG_THRESHOLD_IN_MS;
             }
             else
             {
-                // 60ms should be enough for decoder with resolution smaller than 8k
-                MediaResetParam.watchdogCountThreshold = MHW_MI_DEFAULT_WATCHDOG_THRESHOLD_IN_MS;
+                MediaResetParam.watchdogCountThreshold = MHW_MI_DECODER_720P_WATCHDOG_THRESHOLD_IN_MS;
             }
         }
 
@@ -667,7 +668,8 @@ public:
                 cmd.DW1.StateCacheInvalidationEnable    = params.bInvalidateStateCache;
                 cmd.DW1.ConstantCacheInvalidationEnable = params.bInvalidateConstantCache;
             }
-
+            cmd.DW0.UnTypedDataPortCacheFlush        = params.bUnTypedDataPortCacheFlush;
+            cmd.DW0.HdcPipelineFlush                 = params.bHdcPipelineFlush;
             cmd.DW1.RenderTargetCacheFlushEnable     = params.bFlushRenderTargetCache;
             cmd.DW1.DcFlushEnable                    = params.bFlushRenderTargetCache;  // same as above
             cmd.DW1.VfCacheInvalidationEnable        = params.bInvalidateVFECache;
@@ -912,6 +914,12 @@ public:
             cmd.DW2.ScalableModePipeLock   = params.scalableModePipeLock;
             cmd.DW2.ScalableModePipeUnlock = params.scalableModePipeUnlock;
         }
+        MEDIA_WA_TABLE *pWaTable = this->m_osItf->pfnGetWaTable(this->m_osItf);
+        MHW_MI_CHK_NULL(pWaTable);
+        if (MEDIA_IS_WA(pWaTable, Wa_16021867713))
+        {
+            cmd.DW1.VdboxPipelineArchitectureClockgateDisable = 1;
+        }
 
         return MOS_STATUS_SUCCESS;
     }
@@ -1024,7 +1032,35 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
-MEDIA_CLASS_DEFINE_END(mhw__mi__xe_lpm_plus_base_next__Impl)
+    MOS_STATUS AddBLTMMIOPrologCmd(
+        PMOS_COMMAND_BUFFER cmdBuffer) override
+    {
+        MOS_STATUS eStatus          = MOS_STATUS_SUCCESS;
+        uint64_t   auxTableBaseAddr = 0;
+
+        MHW_CHK_NULL_RETURN(cmdBuffer);
+        MHW_CHK_NULL_RETURN(this->m_osItf);
+
+        auxTableBaseAddr = this->m_osItf->pfnGetAuxTableBaseAddr(this->m_osItf);
+
+        if (auxTableBaseAddr)
+        {
+            auto &par      = MHW_GETPAR_F(MI_LOAD_REGISTER_IMM)();
+            par            = {};
+            par.dwData     = (auxTableBaseAddr & 0xffffffff);
+            par.dwRegister = GetMmioInterfaces(mhw::mi::MHW_MMIO_BLT_AUX_TABLE_BASE_LOW);
+            MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)
+            (cmdBuffer);
+
+            par.dwData     = ((auxTableBaseAddr >> 32) & 0xffffffff);
+            par.dwRegister = GetMmioInterfaces(mhw::mi::MHW_MMIO_BLT_AUX_TABLE_BASE_HIGH);
+            MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)
+            (cmdBuffer);
+        }
+
+        return eStatus;
+    }
+    MEDIA_CLASS_DEFINE_END(mhw__mi__xe_lpm_plus_base_next__Impl)
 };
 
 }  // namespace xe_lpm_plus_base
