@@ -133,6 +133,7 @@ struct HcpBufferSizePar
     uint32_t                 dwPicWidth;
     uint32_t                 dwPicHeight;
     uint32_t                 dwMaxFrameSize;
+    uint32_t                 dwBufferSize;
 };
 
 struct HcpVdboxRowStorePar
@@ -281,7 +282,7 @@ struct _MHW_PAR_T(HCP_PIC_STATE)
     uint8_t  bNotFirstPass                           = 0;
     PCODEC_HEVC_EXT_PIC_PARAMS pHevcExtPicParams     = nullptr;
     PCODEC_HEVC_SCC_PIC_PARAMS pHevcSccPicParams     = nullptr;
-    __MHW_VDBOX_HCP_WRAPPER_EXT(HCP_PIC_STATE_CMDPAR_EXT);
+    bool     hcpPicStatePar0                         = false;
 };
 
 struct _MHW_PAR_T(HCP_SURFACE_STATE)
