@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021-2022 Intel Corporation
+* Copyright (c) 2021-2023 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -139,7 +139,7 @@ struct _MHW_PAR_T(MFX_PIPE_MODE_SELECT)
     bool     shortFormatInUse                               = false;
     bool     vc1OddFrameHeight                              = false;
     uint32_t mediaSoftResetCounterPer1000Clocks             = 0;
-    bool     streamOutEnabled                               = false;
+    bool     sliceSizeStreamout32bit                        = false;
 };
 
 struct _MHW_PAR_T(MFX_SURFACE_STATE)
@@ -287,6 +287,7 @@ struct _MHW_PAR_T(MFX_AVC_IMG_STATE)
     uint32_t                  numMBs                                       = 0;
     uint32_t                  imgStructImageStructureImgStructure10        = 0;
     uint32_t                  interViewOrderDisable                        = 0;
+    bool                      mfxAvcImgStatePar0                           = false;
     
     __MHW_VDBOX_MFX_WRAPPER_EXT(MFX_AVC_IMG_STATE_CMDPAR_EXT);
 };
@@ -323,7 +324,7 @@ struct _MHW_PAR_T(MFX_AVC_SLICE_STATE)
     uint8_t                   numberOfReferencePicturesInInterPredictionList1 = 0;
     uint8_t                   sliceAlphaC0OffsetDiv2                          = 0;
     uint8_t                   sliceBetaOffsetDiv2                             = 0;
-    uint8_t                   sliceQuantizationParameter                      = 0;
+    int8_t                    sliceQuantizationParameter                      = 0;
     uint8_t                   cabacInitIdc10                                  = 0;
     uint8_t                   disableDeblockingFilterIndicator                = 0;
     uint8_t                   directPredictionType                            = 0;
@@ -734,7 +735,7 @@ struct _MHW_PAR_T(MFD_IT_OBJECT)
 
 struct _MHW_PAR_T(MFD_IT_OBJECT_MPEG2_INLINE_DATA)
 {
-    CodecDecodeMpeg2MbParmas *pMBParams = nullptr;
+    CodecDecodeMpeg2MbParams *pMBParams = nullptr;
 
     int32_t CodingType     = 0;
     int16_t sPackedMVs0[4] = {};
