@@ -50,8 +50,6 @@ MediaCopyBaseState::MediaCopyBaseState():
 
 MediaCopyBaseState::~MediaCopyBaseState()
 {
-    MOS_STATUS              eStatus;
-
     if (m_osInterface)
     {
         m_osInterface->pfnDestroy(m_osInterface, false);
@@ -92,7 +90,7 @@ MOS_STATUS MediaCopyBaseState::Initialize(PMOS_INTERFACE osInterface)
     Mos_SetVirtualEngineSupported(m_osInterface, true);
     m_osInterface->pfnVirtualEngineSupported(m_osInterface, true, true);
 
-   #if (_DEBUG || _RELEASE_INTERNAL)
+#if (_DEBUG || _RELEASE_INTERNAL)
     if (m_surfaceDumper == nullptr)
     {
        m_surfaceDumper = MOS_New(CommonSurfaceDumper, osInterface);
@@ -100,6 +98,8 @@ MOS_STATUS MediaCopyBaseState::Initialize(PMOS_INTERFACE osInterface)
     }
     MediaUserSettingSharedPtr           userSettingPtr = nullptr;
 
+    m_surfaceDumper->GetSurfaceDumpLocation(m_dumpLocation_in, mcpy_in);
+    m_surfaceDumper->GetSurfaceDumpLocation(m_dumpLocation_out, mcpy_out);
     if (m_osInterface)
     {
         userSettingPtr = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
@@ -108,9 +108,14 @@ MOS_STATUS MediaCopyBaseState::Initialize(PMOS_INTERFACE osInterface)
             m_MCPYForceMode,
             __MEDIA_USER_FEATURE_SET_MCPY_FORCE_MODE,
             MediaUserSetting::Group::Device);
-    }
 
-   #endif
+        ReadUserSettingForDebug(
+            userSettingPtr,
+            m_enableVeCopySmallRes,
+            __MEDIA_USER_FEATURE_ENABLE_VECOPY_SMALL_RESOLUTION,
+            MediaUserSetting::Group::Device);
+    }
+#endif
     return MOS_STATUS_SUCCESS;
 }
 
@@ -121,7 +126,12 @@ MOS_STATUS MediaCopyBaseState::Initialize(PMOS_INTERFACE osInterface)
 //! \return   MOS_STATUS
 //!           Return MOS_STATUS_SUCCESS if support, otherwise return unspoort.
 //!
-MOS_STATUS MediaCopyBaseState::CapabilityCheck(MCPY_STATE_PARAMS &mcpySrc, MCPY_STATE_PARAMS &mcpyDst, MCPY_ENGINE_CAPS &caps, MCPY_METHOD preferMethod)
+MOS_STATUS MediaCopyBaseState::CapabilityCheck(
+    MOS_FORMAT         format,
+    MCPY_STATE_PARAMS &mcpySrc,
+    MCPY_STATE_PARAMS &mcpyDst,
+    MCPY_ENGINE_CAPS  &caps,
+    MCPY_METHOD        preferMethod)
 {
     // derivate class specific check. include HW engine avaliable check.
     MCPY_CHK_STATUS_RETURN(FeatureSupport(mcpySrc.OsRes, mcpyDst.OsRes, mcpySrc, mcpyDst, caps));
@@ -140,6 +150,11 @@ MOS_STATUS MediaCopyBaseState::CapabilityCheck(MCPY_STATE_PARAMS &mcpySrc, MCPY_
         mcpySrc.bAuxSuface)
     {
         caps.engineVebox = false;
+        // temp solution for FP16 enabling on new platform
+        if (format == Format_A16B16G16R16F || format == Format_A16R16G16B16F)
+        {
+            return MOS_STATUS_UNIMPLEMENTED;
+        }
     }
 
     // Eu cap check.
@@ -180,19 +195,19 @@ MOS_STATUS MediaCopyBaseState::PreCheckCpCopy(
 //! \return   MOS_STATUS
 //!           Return MOS_STATUS_SUCCESS if support, otherwise return unspoort.
 //!
-MOS_STATUS MediaCopyBaseState::CopyEnigneSelect(MCPY_METHOD preferMethod, MCPY_ENGINE& mcpyEngine, MCPY_ENGINE_CAPS& caps)
+MOS_STATUS MediaCopyBaseState::CopyEnigneSelect(MCPY_METHOD& preferMethod, MCPY_ENGINE& mcpyEngine, MCPY_ENGINE_CAPS& caps)
 {
     // driver should make sure there is at least one he can process copy even customer choice doesn't match caps.
     switch (preferMethod)
     {
         case MCPY_METHOD_PERFORMANCE:
-        case MCPY_METHOD_DEFAULT:
             mcpyEngine = caps.engineRender?MCPY_ENGINE_RENDER:(caps.engineBlt ? MCPY_ENGINE_BLT : MCPY_ENGINE_VEBOX);
             break;
         case MCPY_METHOD_BALANCE:
             mcpyEngine = caps.engineVebox?MCPY_ENGINE_VEBOX:(caps.engineBlt?MCPY_ENGINE_BLT:MCPY_ENGINE_RENDER);
             break;
         case MCPY_METHOD_POWERSAVING:
+        case MCPY_METHOD_DEFAULT:
             mcpyEngine = caps.engineBlt?MCPY_ENGINE_BLT:(caps.engineVebox?MCPY_ENGINE_VEBOX:MCPY_ENGINE_RENDER);
             break;
         default:
@@ -211,7 +226,7 @@ MOS_STATUS MediaCopyBaseState::CopyEnigneSelect(MCPY_METHOD preferMethod, MCPY_E
     {
         mcpyEngine = MCPY_ENGINE_VEBOX;
     }
-    else if (4 == m_MCPYForceMode)
+    else if (MCPY_METHOD_DEFAULT != m_MCPYForceMode)
     {
         return MOS_STATUS_INVALID_PARAMETER; // bypass copy engine, just let APP handle it.
     }
@@ -252,6 +267,15 @@ uint32_t GetMinRequiredSurfaceSizeInBytes(uint32_t pitch, uint32_t height, MOS_F
     case Format_P8:
     case Format_L8:
     case Format_A8:
+    case Format_Y16U:
+    case Format_A16B16G16R16F:
+    case Format_A16R16G16B16F:
+    case Format_A16B16G16R16:
+    case Format_A16R16G16B16:
+    case Format_IRW0:
+    case Format_IRW1:
+    case Format_IRW2:
+    case Format_IRW3:
         nBytes = pitch * height;
         break;
     default:
@@ -261,7 +285,7 @@ uint32_t GetMinRequiredSurfaceSizeInBytes(uint32_t pitch, uint32_t height, MOS_F
     return nBytes;
 }
 
-MOS_STATUS CheckResourceSizeValidForCopy(MOS_SURFACE &res, MCPY_ENGINE method)
+MOS_STATUS MediaCopyBaseState::CheckResourceSizeValidForCopy(const MOS_SURFACE &res, const MCPY_ENGINE method)
 {
     if (res.TileType != MOS_TILE_LINEAR)
     {
@@ -295,7 +319,7 @@ MOS_STATUS CheckResourceSizeValidForCopy(MOS_SURFACE &res, MCPY_ENGINE method)
         }
     }
 
-    if (method == MCPY_ENGINE_BLT || method == MCPY_ENGINE_RENDER)
+    if (method == MCPY_ENGINE_RENDER)
     {
         if (res.dwHeight < RENDER_MIN_HEIGHT || res.dwWidth < RENDER_MIN_WIDTH)
         {
@@ -309,19 +333,40 @@ MOS_STATUS CheckResourceSizeValidForCopy(MOS_SURFACE &res, MCPY_ENGINE method)
 
     if (method == MCPY_ENGINE_VEBOX)
     {
-        if (res.dwHeight < VE_MIN_HEIGHT || res.dwWidth < VE_MIN_WIDTH)
+#if (_DEBUG || _RELEASE_INTERNAL)
+        if (!m_enableVeCopySmallRes)
+#endif
         {
-            MT_ERR2(MT_MEDIA_COPY,
-                MT_SURF_WIDTH, res.dwWidth,
-                MT_SURF_HEIGHT, res.dwHeight);
-            MCPY_ASSERTMESSAGE("Surface size not meet min requirement! height %d, width %d", res.dwHeight, res.dwWidth);
-            return MOS_STATUS_INVALID_PARAMETER;
+            if (res.dwHeight < VE_MIN_HEIGHT || res.dwWidth < VE_MIN_WIDTH)
+            {
+                MT_ERR2(MT_MEDIA_COPY,
+                    MT_SURF_WIDTH, res.dwWidth,
+                    MT_SURF_HEIGHT, res.dwHeight);
+                MCPY_ASSERTMESSAGE("Surface size not meet min requirement! height %d, width %d", res.dwHeight, res.dwWidth);
+                return MOS_STATUS_INVALID_PARAMETER;
+            }
         }
     }
 
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS MediaCopyBaseState::ValidateResource(const MOS_SURFACE &src, const MOS_SURFACE &dst, MCPY_ENGINE method)
+{
+    // For CP buffer copy, CP will handle the overflown size, skip size check
+    if (src.OsResource.pGmmResInfo->GetResourceType() == RESOURCE_BUFFER &&
+        dst.OsResource.pGmmResInfo->GetResourceType() == RESOURCE_BUFFER &&
+        method == MCPY_ENGINE_BLT)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+    MCPY_CHK_STATUS_RETURN(CheckResourceSizeValidForCopy(src, method));
+    MCPY_CHK_STATUS_RETURN(CheckResourceSizeValidForCopy(dst, method));
+
+    return MOS_STATUS_SUCCESS;
+}
+
 //!
 //! \brief    surface copy func.
 //! \details  copy surface.
@@ -339,8 +384,10 @@ MOS_STATUS MediaCopyBaseState::SurfaceCopy(PMOS_RESOURCE src, PMOS_RESOURCE dst,
     MOS_SURFACE SrcResDetails, DstResDetails;
     MOS_ZeroMemory(&SrcResDetails, sizeof(MOS_SURFACE));
     MOS_ZeroMemory(&DstResDetails, sizeof(MOS_SURFACE));
-    SrcResDetails.Format = Format_Invalid;
-    DstResDetails.Format = Format_Invalid;
+    SrcResDetails.Format     = Format_Invalid;
+    SrcResDetails.OsResource = *src;
+    DstResDetails.Format     = Format_Invalid;
+    DstResDetails.OsResource = *dst;
 
     MCPY_STATE_PARAMS     mcpySrc = {nullptr, MOS_MMC_DISABLED, MOS_TILE_LINEAR, MCPY_CPMODE_CLEAR, false};
     MCPY_STATE_PARAMS     mcpyDst = {nullptr, MOS_MMC_DISABLED, MOS_TILE_LINEAR, MCPY_CPMODE_CLEAR, false};
@@ -352,13 +399,16 @@ MOS_STATUS MediaCopyBaseState::SurfaceCopy(PMOS_RESOURCE src, PMOS_RESOURCE dst,
     mcpySrc.CpMode   = src->pGmmResInfo->GetSetCpSurfTag(false, 0)?MCPY_CPMODE_CP:MCPY_CPMODE_CLEAR;
     mcpySrc.TileMode = SrcResDetails.TileType;
     mcpySrc.OsRes    = src;
-    MCPY_NORMALMESSAGE("input surface's format %d, width %d; hight %d, pitch %d, tiledmode %d, mmc mode %d",
+    MCPY_NORMALMESSAGE("input surface's format %d, width %d; hight %d, pitch %d, tiledmode %d, mmc mode %d, cp mode %d, ResType %d, preferMethod %d",
         SrcResDetails.Format,
         SrcResDetails.dwWidth,
         SrcResDetails.dwHeight,
         SrcResDetails.dwPitch,
         mcpySrc.TileMode,
-        mcpySrc.CompressionMode);
+        mcpySrc.CompressionMode,
+        mcpySrc.CpMode,
+        src->pGmmResInfo->GetResourceType(),
+        preferMethod);
     MT_LOG7(MT_MEDIA_COPY, MT_NORMAL, 
         MT_SURF_PITCH,          SrcResDetails.dwPitch,
         MT_SURF_HEIGHT,         SrcResDetails.dwHeight,
@@ -373,13 +423,15 @@ MOS_STATUS MediaCopyBaseState::SurfaceCopy(PMOS_RESOURCE src, PMOS_RESOURCE dst,
     mcpyDst.CpMode   = dst->pGmmResInfo->GetSetCpSurfTag(false, 0)?MCPY_CPMODE_CP:MCPY_CPMODE_CLEAR;
     mcpyDst.TileMode = DstResDetails.TileType;
     mcpyDst.OsRes    = dst;
-    MCPY_NORMALMESSAGE("Output surface's format %d, width %d; hight %d, pitch %d, tiledmode %d, mmc mode %d",
+    MCPY_NORMALMESSAGE("Output surface's format %d, width %d; hight %d, pitch %d, tiledmode %d, mmc mode %d,cp mode %d, ResType %d",
         DstResDetails.Format,
         DstResDetails.dwWidth,
         DstResDetails.dwHeight,
         DstResDetails.dwPitch,
         mcpyDst.TileMode,
-        mcpyDst.CompressionMode);
+        mcpyDst.CompressionMode,
+        mcpyDst.CpMode,
+        dst->pGmmResInfo->GetResourceType());
     MT_LOG7(MT_MEDIA_COPY, MT_NORMAL, 
         MT_SURF_PITCH,          DstResDetails.dwPitch,
         MT_SURF_HEIGHT,         DstResDetails.dwHeight,
@@ -391,12 +443,13 @@ MOS_STATUS MediaCopyBaseState::SurfaceCopy(PMOS_RESOURCE src, PMOS_RESOURCE dst,
 
     MCPY_CHK_STATUS_RETURN(PreCheckCpCopy(mcpySrc, mcpyDst, preferMethod));
 
-    MCPY_CHK_STATUS_RETURN(CapabilityCheck(mcpySrc, mcpyDst, mcpyEngineCaps, preferMethod));
+    MCPY_CHK_STATUS_RETURN(CapabilityCheck(SrcResDetails.Format,
+        mcpySrc, mcpyDst,
+        mcpyEngineCaps, preferMethod));
 
     CopyEnigneSelect(preferMethod, mcpyEngine, mcpyEngineCaps);
 
-    MCPY_CHK_STATUS_RETURN(CheckResourceSizeValidForCopy(SrcResDetails, mcpyEngine));
-    MCPY_CHK_STATUS_RETURN(CheckResourceSizeValidForCopy(DstResDetails, mcpyEngine));
+    MCPY_CHK_STATUS_RETURN(ValidateResource(SrcResDetails, DstResDetails, mcpyEngine));
 
     MCPY_CHK_STATUS_RETURN(TaskDispatch(mcpySrc, mcpyDst, mcpyEngine));
 
@@ -412,12 +465,6 @@ MOS_STATUS MediaCopyBaseState::TaskDispatch(MCPY_STATE_PARAMS mcpySrc, MCPY_STAT
     MOS_SURFACE sourceSurface = {};
     MOS_SURFACE targetSurface = {};
 
-    char  dumpLocation_in[MAX_PATH];
-    char  dumpLocation_out[MAX_PATH];
-
-    MOS_ZeroMemory(dumpLocation_in, MAX_PATH);
-    MOS_ZeroMemory(dumpLocation_out, MAX_PATH);
-
     targetSurface.Format = Format_Invalid;
     targetSurface.OsResource = *mcpyDst.OsRes;
 
@@ -433,17 +480,16 @@ MOS_STATUS MediaCopyBaseState::TaskDispatch(MCPY_STATE_PARAMS mcpySrc, MCPY_STAT
 
     // Set the dump location like "dumpLocation before MCPY=path_to_dump_folder" in user feature configure file
     // Otherwise, the surface may not be dumped
-    if (m_surfaceDumper)
+    // Only dump linear surface
+    if (m_surfaceDumper && mcpySrc.TileMode == MOS_TILE_LINEAR)
     {
-        m_surfaceDumper->GetSurfaceDumpLocation(dumpLocation_in, mcpy_in);
-
-        if ((*dumpLocation_in == '\0') || (*dumpLocation_in == ' '))
+        if ((*m_dumpLocation_in == '\0') || (*m_dumpLocation_in == ' '))
         {
             MCPY_NORMALMESSAGE("Invalid dump location set, the surface will not be dumped");
         }
         else
         {
-            m_surfaceDumper->DumpSurfaceToFile(m_osInterface, &sourceSurface, dumpLocation_in, m_surfaceDumper->m_frameNum, true, false, nullptr);
+            m_surfaceDumper->DumpSurfaceToFile(m_osInterface, &sourceSurface, m_dumpLocation_in, m_surfaceDumper->m_frameNum, true, false, nullptr);
         }
     }
 #endif
@@ -455,16 +501,6 @@ MOS_STATUS MediaCopyBaseState::TaskDispatch(MCPY_STATE_PARAMS mcpySrc, MCPY_STAT
             eStatus = MediaVeboxCopy(mcpySrc.OsRes, mcpyDst.OsRes);
             break;
         case MCPY_ENGINE_BLT:
-            if ((mcpySrc.TileMode != MOS_TILE_LINEAR) && (mcpySrc.CompressionMode != MOS_MMC_DISABLED))
-            {
-                MCPY_NORMALMESSAGE("mmc on, mcpySrc.TileMode= %d, mcpySrc.CompressionMode = %d", mcpySrc.TileMode, mcpySrc.CompressionMode);
-                eStatus = m_osInterface->pfnDecompResource(m_osInterface, mcpySrc.OsRes);
-                if (MOS_STATUS_SUCCESS != eStatus)
-                {
-                    MosUtilities::MosUnlockMutex(m_inUseGPUMutex);
-                    MCPY_CHK_STATUS_RETURN(eStatus);
-                }
-            }
             if ((mcpyDst.TileMode != MOS_TILE_LINEAR) && (mcpyDst.CompressionMode == MOS_MMC_RC))
             {
                 MCPY_NORMALMESSAGE("mmc on, mcpyDst.TileMode= %d, mcpyDst.CompressionMode = %d", mcpyDst.TileMode, mcpyDst.CompressionMode);
@@ -486,27 +522,29 @@ MOS_STATUS MediaCopyBaseState::TaskDispatch(MCPY_STATE_PARAMS mcpySrc, MCPY_STAT
     MosUtilities::MosUnlockMutex(m_inUseGPUMutex);
 
 #if (_DEBUG || _RELEASE_INTERNAL)
-    std::string copyEngine = mcpyEngine ?(mcpyEngine == MCPY_ENGINE_BLT?"BLT":"Render"):"VeBox";
-    MediaUserSettingSharedPtr userSettingPtr = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
-    ReportUserSettingForDebug(
-        userSettingPtr,
-        __MEDIA_USER_FEATURE_MCPY_MODE,
-        copyEngine,
-        MediaUserSetting::Group::Device);
+    if (m_bRegReport)
+    {
+        std::string copyEngine = mcpyEngine ?(mcpyEngine == MCPY_ENGINE_BLT?"BLT":"Render"):"VeBox";
+        MediaUserSettingSharedPtr userSettingPtr = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
+        ReportUserSettingForDebug(
+            userSettingPtr,
+            __MEDIA_USER_FEATURE_MCPY_MODE,
+            copyEngine,
+            MediaUserSetting::Group::Device);
+    }
 
     // Set the dump location like "dumpLocation after MCPY=path_to_dump_folder" in user feature configure file
     // Otherwise, the surface may not be dumped
-    if (m_surfaceDumper)
+    // Only dump linear surface
+    if (m_surfaceDumper && mcpyDst.TileMode == MOS_TILE_LINEAR)
     {
-        m_surfaceDumper->GetSurfaceDumpLocation(dumpLocation_out, mcpy_out);
-
-        if ((*dumpLocation_out == '\0') || (*dumpLocation_out == ' '))
+        if ((*m_dumpLocation_out == '\0') || (*m_dumpLocation_out == ' '))
         {
             MCPY_NORMALMESSAGE("Invalid dump location set, the surface will not be dumped");
         }
         else
         {
-            m_surfaceDumper->DumpSurfaceToFile(m_osInterface, &targetSurface, dumpLocation_out, m_surfaceDumper->m_frameNum, true, false, nullptr);
+            m_surfaceDumper->DumpSurfaceToFile(m_osInterface, &targetSurface, m_dumpLocation_out, m_surfaceDumper->m_frameNum, true, false, nullptr);
         }
         m_surfaceDumper->m_frameNum++;
     }
@@ -533,3 +571,7 @@ MOS_STATUS MediaCopyBaseState::AuxCopy(PMOS_RESOURCE src, PMOS_RESOURCE dst)
     return MOS_STATUS_INVALID_HANDLE;
 }
 
+PMOS_INTERFACE MediaCopyBaseState::GetMosInterface()
+{
+    return m_osInterface;
+}
\ No newline at end of file
