@@ -101,6 +101,8 @@ public:
     //!
     //! \brief    check copy capability.
     //! \details  to determine surface copy is supported or not.
+    //! \param    format
+    //!           [in] surface format
     //! \param    mcpySrc
     //!           [in] Pointer to source paramters
     //! \param    mcpyDst
@@ -110,7 +112,12 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if support, otherwise return unspoort.
     //!
-    virtual MOS_STATUS CapabilityCheck(MCPY_STATE_PARAMS &mcpySrc, MCPY_STATE_PARAMS &mcpyDst, MCPY_ENGINE_CAPS &caps, MCPY_METHOD preferMethod);
+    virtual MOS_STATUS CapabilityCheck(
+        MOS_FORMAT         format,
+        MCPY_STATE_PARAMS &mcpySrc,
+        MCPY_STATE_PARAMS &mcpyDst,
+        MCPY_ENGINE_CAPS  &caps,
+        MCPY_METHOD        preferMethod);
 
     //!
     //! \brief    surface copy pre process.
@@ -161,6 +168,15 @@ public:
         return false;
     }
 
+    virtual PMOS_INTERFACE GetMosInterface();
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    virtual void SetRegkeyReport(bool flag)
+    {
+        m_bRegReport = flag;
+    }
+#endif
+
 protected:
 
     //!
@@ -233,7 +249,7 @@ protected:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if support, otherwise return unspoort.
     //!
-    MOS_STATUS CopyEnigneSelect(MCPY_METHOD preferMethod, MCPY_ENGINE& mcpyEngine, MCPY_ENGINE_CAPS& caps);
+    virtual MOS_STATUS CopyEnigneSelect(MCPY_METHOD& preferMethod, MCPY_ENGINE &mcpyEngine, MCPY_ENGINE_CAPS &caps);
 
     //!
     //! \brief    use blt engie to do surface copy.
@@ -274,17 +290,23 @@ protected:
     virtual MOS_STATUS MediaVeboxCopy(PMOS_RESOURCE src, PMOS_RESOURCE dst)
     {return MOS_STATUS_SUCCESS;}
 
-public:
-    PMOS_INTERFACE        m_osInterface    = nullptr;
-    bool                  m_allowCPBltCopy = false;  // allow cp call media copy only for output clear cases.
-#if (_DEBUG || _RELEASE_INTERNAL)
-    CommonSurfaceDumper  *m_surfaceDumper  = nullptr;
-    int                  m_MCPYForceMode   = 0;
-#endif
+    MOS_STATUS CheckResourceSizeValidForCopy(const MOS_SURFACE &res, const MCPY_ENGINE method);
+    MOS_STATUS ValidateResource(const MOS_SURFACE &src, const MOS_SURFACE &dst, MCPY_ENGINE method);
 
+public:
+    PMOS_INTERFACE       m_osInterface    = nullptr;
+    bool                 m_allowCPBltCopy = false;  // allow cp call media copy only for output clear cases.
 
 protected:
-    PMOS_MUTEX           m_inUseGPUMutex = nullptr; // Mutex for in-use GPU context
+    PMOS_MUTEX           m_inUseGPUMutex        = nullptr; // Mutex for in-use GPU context
+#if (_DEBUG || _RELEASE_INTERNAL)
+    CommonSurfaceDumper *m_surfaceDumper        = nullptr;
+    int                  m_MCPYForceMode        = 0;
+    bool                 m_enableVeCopySmallRes = false;
+    bool                 m_bRegReport           = true;
+    char                 m_dumpLocation_in[MAX_PATH]  = {};
+    char                 m_dumpLocation_out[MAX_PATH] = {};
+#endif
 MEDIA_CLASS_DEFINE_END(MediaCopyBaseState)
 };
 #endif
