@@ -852,6 +852,17 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
         return eStatus;
     }
 
+    // reuse the allocated buffer if the allocated size was larger than request size when OptimizeCpuTiming is enabled
+    if (m_osInterface->bOptimizeCpuTiming                               &&
+        surface                                                         &&
+        surface->osSurface                                              &&
+        (!Mos_ResourceIsNull(&surface->osSurface->OsResource))          &&
+        (Format_Buffer                                == format)        &&
+        (surface->bufferWidth * surface->bufferHeight >= width * height))
+    {
+        return eStatus;
+    }
+
     if (surface && nullptr == surface->osSurface)
     {
         // VP_SURFACE should always be allocated by interface in VpAllocator,
@@ -988,6 +999,15 @@ MOS_STATUS VpAllocator::ReAllocateSurface(
         return eStatus;
     }
 
+    // reuse the allocated buffer if the allocated size was larger than request size when OptimizeCpuTiming is enabled
+    if (m_osInterface->bOptimizeCpuTiming                       &&
+        (!Mos_ResourceIsNull(&surface->OsResource))           &&
+        (Format_Buffer                        == format)        &&
+        (surface->dwWidth * surface->dwHeight >= width * height))
+    {
+        return eStatus;
+    }
+
     MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
 
     VpHal_AllocParamsInitType(&allocParams, surface, defaultResType, defaultTileType);
@@ -1449,3 +1469,18 @@ MOS_STATUS VpAllocator::SetMmcFlags(MOS_SURFACE &osSurface)
 
     return MOS_STATUS_SUCCESS;
 }
+
+MOS_HW_RESOURCE_DEF VpAllocator::GetResourceCache(uint32_t feature, bool bOut, ENGINE_TYPE engineType, MOS_COMPONENT id)
+{
+    VP_FUNC_CALL();
+    MOS_CACHE_ELEMENT element(MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC, MOS_CODEC_RESOURCE_USAGE_BEGIN_CODEC);
+    bool              res = m_osInterface->pfnGetCacheSetting(id, SUFACE_TYPE_ASSIGNED(feature), bOut, engineType, element, false);
+    if (res == false)
+    {
+        VP_PUBLIC_ASSERTMESSAGE("Resource %u was not found in cache manager, use default usage MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_RENDER!", feature);
+        return MOS_HW_RESOURCE_USAGE_VP_INTERNAL_READ_WRITE_RENDER;
+    }
+
+    VP_PUBLIC_NORMALMESSAGE("Resource %u was found in cache manager, use mocs usage %u!", feature, element.mocsUsageType);
+    return element.mocsUsageType;
+}
\ No newline at end of file
