@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2023, Intel Corporation
+* Copyright (c) 2018-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -802,6 +802,13 @@ MOS_STATUS VpResourceManager::GetIntermediaOutputSurfaceParams(VP_EXECUTE_CAPS&
         params.rcSrc = scaling->GetSwFilterParams().output.rcSrc;
         params.rcDst = scaling->GetSwFilterParams().output.rcDst;
         params.rcMaxSrc = scaling->GetSwFilterParams().output.rcMaxSrc;
+
+        if (scaling->GetSwFilterParams().interlacedScalingType == ISCALING_INTERLEAVED_TO_FIELD)
+        {
+            params.height = scaling->GetSwFilterParams().output.dwHeight / 2;
+            params.rcDst.bottom = params.rcDst.bottom / 2;
+            params.rcMaxSrc.bottom = params.rcMaxSrc.bottom / 2;
+        }
     }
     else
     {
@@ -1214,15 +1221,37 @@ MOS_STATUS VpResourceManager::AssignExecuteResource(VP_EXECUTE_CAPS& caps, std::
     return MOS_STATUS_SUCCESS;
 }
 
+VPHAL_CSPACE GetDemosaicOutputColorSpace(VPHAL_CSPACE colorSpace)
+{
+    return IS_COLOR_SPACE_BT2020(colorSpace) ? CSpace_BT2020_RGB : CSpace_sRGB;
+}
+
+MOS_FORMAT GetDemosaicOutputFormat(VPHAL_CSPACE colorSpace)
+{
+    return IS_COLOR_SPACE_BT2020(colorSpace) ? Format_R10G10B10A2 : Format_A8B8G8R8;
+}
+
 MOS_STATUS GetVeboxOutputParams(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputFormat, MOS_TILE_TYPE inputTileType, MOS_FORMAT outputFormat,
-                                MOS_FORMAT &veboxOutputFormat, MOS_TILE_TYPE &veboxOutputTileType)
+                                MOS_FORMAT &veboxOutputFormat, MOS_TILE_TYPE &veboxOutputTileType, VPHAL_CSPACE colorSpaceOutput)
 {
     VP_FUNC_CALL();
 
     // Vebox Chroma Co-Sited downsampleing is part of VEO. It only affects format of vebox output surface, but not
     // affect sfc input format, that's why different logic between GetSfcInputFormat and GetVeboxOutputParams.
     // Check DI first and downsampling to NV12 if possible to save bandwidth no matter IECP enabled or not.
-    if (executeCaps.bDI || executeCaps.bDiProcess2ndField)
+    if (executeCaps.b3DlutOutput)
+    {
+        if (IS_RGB64_FLOAT_FORMAT(outputFormat))  // SFC output FP16, YUV->ABGR16
+        {
+            veboxOutputFormat = Format_A16B16G16R16;
+        }
+        else
+        {
+            veboxOutputFormat = IS_COLOR_SPACE_BT2020(colorSpaceOutput) ? Format_R10G10B10A2 : Format_A8B8G8R8;
+        }
+        veboxOutputTileType = inputTileType;
+    }
+    else if (executeCaps.bDI || executeCaps.bDiProcess2ndField)
     {
         // NV12 will be used if target output is not YUV2 to save bandwidth.
         if (outputFormat == Format_YUY2)
@@ -1248,6 +1277,11 @@ MOS_STATUS GetVeboxOutputParams(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputFo
         veboxOutputFormat = Format_AYUV;
         veboxOutputTileType = inputTileType;
     }
+    else if (executeCaps.bDemosaicInUse)
+    {
+        veboxOutputFormat = GetDemosaicOutputFormat(colorSpaceOutput);
+        veboxOutputTileType = inputTileType;
+    }
     else
     {
         veboxOutputFormat = inputFormat;
@@ -1257,7 +1291,8 @@ MOS_STATUS GetVeboxOutputParams(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputFo
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_FORMAT GetSfcInputFormat(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputFormat, VPHAL_CSPACE colorSpaceOutput)
+
+MOS_FORMAT GetSfcInputFormat(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputFormat, VPHAL_CSPACE colorSpaceOutput, MOS_FORMAT outputFormat)
 {
     VP_FUNC_CALL();
 
@@ -1267,7 +1302,14 @@ MOS_FORMAT GetSfcInputFormat(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputForma
     // Then Check IECP, since IECP is done after DI, and the vebox downsampling not affect the vebox input.
     if (executeCaps.b3DlutOutput)
     {
-        return IS_COLOR_SPACE_BT2020(colorSpaceOutput) ? Format_R10G10B10A2 : Format_A8B8G8R8;
+        if (IS_RGB64_FLOAT_FORMAT(outputFormat))    // SFC output FP16, YUV->ABGR16
+        {
+            return Format_A16B16G16R16;
+        }
+        else
+        {
+            return IS_COLOR_SPACE_BT2020(colorSpaceOutput) ? Format_R10G10B10A2 : Format_A8B8G8R8;
+        }
     }
     else if (executeCaps.bIECP && executeCaps.bCGC && executeCaps.bBt2020ToRGB)
     {
@@ -1288,6 +1330,10 @@ MOS_FORMAT GetSfcInputFormat(VP_EXECUTE_CAPS &executeCaps, MOS_FORMAT inputForma
         // set to YUY2 here.
         return Format_YUY2;
     }
+    else if (executeCaps.bDemosaicInUse)
+    {
+        return GetDemosaicOutputFormat(colorSpaceOutput);
+    }
 
     return inputFormat;
 }
@@ -1316,7 +1362,7 @@ MOS_STATUS VpResourceManager::ReAllocateVeboxOutputSurface(VP_EXECUTE_CAPS& caps
     MOS_TILE_TYPE   veboxOutputTileType                 = inputSurface->osSurface->TileType;
 
     VP_PUBLIC_CHK_STATUS_RETURN(GetVeboxOutputParams(caps, inputSurface->osSurface->Format, inputSurface->osSurface->TileType,
-                                            outputSurface->osSurface->Format, veboxOutputFormat, veboxOutputTileType));
+                                            outputSurface->osSurface->Format, veboxOutputFormat, veboxOutputTileType, outputSurface->ColorSpace));
 
     allocated = false;
 
@@ -1326,17 +1372,8 @@ MOS_STATUS VpResourceManager::ReAllocateVeboxOutputSurface(VP_EXECUTE_CAPS& caps
         enableVeboxOutputSurf = m_vpUserFeatureControl->IsVeboxOutputSurfEnabled();
     }
 
-    if (enableVeboxOutputSurf || IS_VP_VEBOX_DN_ONLY(caps))
-    {
-        bSurfCompressible   = inputSurface->osSurface->bCompressible;
-        surfCompressionMode = inputSurface->osSurface->CompressionMode;
-    }
-    else
-    {
-        bSurfCompressible   = true;
-        surfCompressionMode = MOS_MMC_MC;
-
-    }
+    bSurfCompressible   = inputSurface->osSurface->bCompressible;
+    surfCompressionMode = inputSurface->osSurface->CompressionMode;
 
     if (m_currentFrameIds.pastFrameAvailable && m_currentFrameIds.futureFrameAvailable)
     {
@@ -1625,14 +1662,23 @@ MOS_STATUS VpResourceManager::FillLinearBufferWithEncZero(VP_SURFACE *surface, u
     return MOS_STATUS_SUCCESS;
 }
 
-uint32_t VpResourceManager::Get3DLutSize(uint32_t &lutWidth, uint32_t &lutHeight)
+uint32_t VpResourceManager::Get3DLutSize(bool is33LutSizeEnabled, uint32_t &lutWidth, uint32_t &lutHeight)
 {
     VP_FUNC_CALL();
 
-    lutWidth = LUT65_SEG_SIZE * 2;
-    lutHeight = LUT65_SEG_SIZE * LUT65_MUL_SIZE;
-
-    return VP_VEBOX_HDR_3DLUT65;
+    if (is33LutSizeEnabled)
+    {
+        lutWidth  = LUT33_SEG_SIZE * 2;
+        lutHeight = LUT33_SEG_SIZE * LUT33_MUL_SIZE;
+        VP_RENDER_NORMALMESSAGE("3DLut table is used 33 lutsize.");
+        return VP_VEBOX_HDR_3DLUT33;
+    }
+    else
+    {
+        lutWidth = LUT65_SEG_SIZE * 2;
+        lutHeight = LUT65_SEG_SIZE * LUT65_MUL_SIZE;
+        return VP_VEBOX_HDR_3DLUT65;
+    }
 }
 
 uint32_t VpResourceManager::Get1DLutSize()
@@ -1820,7 +1866,7 @@ MOS_STATUS VpResourceManager::AllocateVeboxResource(VP_EXECUTE_CAPS& caps, VP_SU
 
     VP_PUBLIC_CHK_STATUS_RETURN(Allocate3DLut(caps));
 
-    if (caps.bDV || caps.bHDR3DLUT || caps.b3DLutCalc)
+    if (caps.b1K1DLutInUse)
     {
         dwSize = Get1DLutSize();
         VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.ReAllocateSurface(
@@ -1857,7 +1903,7 @@ MOS_STATUS VpResourceManager::Allocate3DLut(VP_EXECUTE_CAPS& caps)
         // HDR
         uint32_t lutWidth = 0;
         uint32_t lutHeight = 0;
-        size = Get3DLutSize(lutWidth, lutHeight);
+        size = Get3DLutSize(caps.bHdr33lutsize, lutWidth, lutHeight);
         VP_PUBLIC_CHK_STATUS_RETURN(m_allocator.ReAllocateSurface(
             m_vebox3DLookUpTables,
             "Vebox3DLutTableSurface",
@@ -1886,11 +1932,23 @@ MOS_STATUS VpResourceManager::AllocateResourceFor3DLutKernel(VP_EXECUTE_CAPS& ca
     uint32_t    lutWidth = 0;
     uint32_t    lutHeight = 0;
 
-    uint32_t sizeOf3DLut = Get3DLutSize(lutWidth, lutHeight);
-    if (VP_VEBOX_HDR_3DLUT65 != sizeOf3DLut)
+    uint32_t sizeOf3DLut = Get3DLutSize(caps.bHdr33lutsize, lutWidth, lutHeight);
+
+    if (caps.bHdr33lutsize)
     {
-        VP_PUBLIC_ASSERTMESSAGE("3DLutSize(%x) != VP_VEBOX_HDR_3DLUT65(%x)", sizeOf3DLut, VP_VEBOX_HDR_3DLUT65);
-        VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+        if (VP_VEBOX_HDR_3DLUT33 != sizeOf3DLut)
+        {
+            VP_PUBLIC_ASSERTMESSAGE("3DLutSize(%x) != VP_VEBOX_HDR_3DLUT33(%x)", sizeOf3DLut, VP_VEBOX_HDR_3DLUT33);
+            VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+        }
+    }
+    else
+    {
+        if (VP_VEBOX_HDR_3DLUT65 != sizeOf3DLut)
+        {
+            VP_PUBLIC_ASSERTMESSAGE("3DLutSize(%x) != VP_VEBOX_HDR_3DLUT65(%x)", sizeOf3DLut, VP_VEBOX_HDR_3DLUT65);
+            VP_PUBLIC_CHK_STATUS_RETURN(MOS_STATUS_INVALID_PARAMETER);
+        }
     }
 
     VP_PUBLIC_CHK_STATUS_RETURN(Allocate3DLut(caps));
@@ -2169,7 +2227,7 @@ MOS_STATUS VpResourceManager::AssignVeboxResource(VP_EXECUTE_CAPS& caps, VP_SURF
         surfGroup.insert(std::make_pair(SurfaceTypeHVSTable, m_veboxDnHVSTables));
     }
 
-    if (Vebox1DlutNeeded(caps) || VeboxHdr3DlutNeeded(caps))
+    if (caps.b1K1DLutInUse)
     {
         // Insert DV 1Dlut surface
         surfGroup.insert(std::make_pair(SurfaceType1k1dLut, m_vebox1DLookUpTables));
