@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2022, Intel Corporation
+* Copyright (c) 2019-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -35,6 +35,7 @@
 #include "vp_render_common.h"
 #include <vector>
 #include "media_sfc_interface.h"
+#include "surface_type.h"
 
 namespace vp
 {
@@ -55,15 +56,6 @@ class SwFilterSubPipe;
 #define FEATURE_TYPE_MASK                   0xffffff00
 #define FEATURE_TYPE_ENGINE_ASSIGNED(feature) (((feature)&FEATURE_TYPE_MASK) != (feature))
 
-#define SURFACETYPE_SIZE32                  31
-#define SURFACETYPE_SIZE16                  15
-#define SURFACETYPE_SIZE5                   4
-#define SURFACETYPE_SIZE10                  9
-
-#define GFSURFACE_COUNT 8
-#define MOTION_CHANNEL 3
-#define MAX_MODELSURFACE_COUNT 85
-
 #define VPHAL_MAX_HDR_INPUT_LAYER           8
 #define VPHAL_MAX_HDR_OUTPUT_LAYER          1
 #define VPHAL_HDR_BTINDEX_LAYER0            16
@@ -75,79 +67,60 @@ class SwFilterSubPipe;
 
 enum FeatureType
 {
-    FeatureTypeInvalid          = 0,
-    FeatureTypeCsc              = 0x100,
-    FeatureTypeCscOnSfc         = FeatureTypeCsc | FEATURE_TYPE_ENGINE_BITS_SFC,
-    FeatureTypeCscOnVebox       = FeatureTypeCsc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeCscOnRender      = FeatureTypeCsc | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeRotMir           = 0x200,
-    FeatureTypeRotMirOnSfc      = FeatureTypeRotMir | FEATURE_TYPE_ENGINE_BITS_SFC,
-    FeatureTypeRotMirOnRender   = FeatureTypeRotMir | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeScaling          = 0x300,
-    FeatureTypeScalingOnSfc     = FeatureTypeScaling | FEATURE_TYPE_ENGINE_BITS_SFC,
-    FeatureTypeScalingOnRender  = FeatureTypeScaling | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeDn               = 0x400,
-    FeatureTypeDnOnVebox        = FeatureTypeDn | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeDnHVSCalOnRender = FeatureTypeDn | FEATURE_TYPE_ENGINE_BITS_RENDER | FEATURE_TYPE_ENGINE_BITS_SUB_STEP,
-    FeatureTypeDi               = 0x500,
-    FeatureTypeDiOnVebox        = FeatureTypeDi | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeDiOnRender       = FeatureTypeDi | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeDiFmdOnRender    = FeatureTypeDi | FEATURE_TYPE_ENGINE_BITS_RENDER | FEATURE_TYPE_ENGINE_BITS_SUB_STEP,
-    FeatureTypeSte              = 0x600,
-    FeatureTypeSteOnVebox       = FeatureTypeSte | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeAce              = 0x700,
-    FeatureTypeAceOnVebox       = FeatureTypeAce | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeVeboxUpdate      = 0x800,
-    FeatureTypeVeboxUpdateOnRender = FeatureTypeVeboxUpdate | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeTcc              = 0x900,
-    FeatureTypeTccOnVebox       = FeatureTypeTcc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeProcamp          = 0xA00,
-    FeatureTypeProcampOnVebox   = FeatureTypeProcamp | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeProcampOnRender  = FeatureTypeProcamp | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeCgc              = 0xB00,
-    FeatureTypeCgcOnVebox       = FeatureTypeCgc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeHdr              = 0xC00,
-    FeatureTypeHdrOnVebox       = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeHdr3DLutCalOnRender = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_RENDER | FEATURE_TYPE_ENGINE_BITS_SUB_STEP,
-    FeatureTypeHdrOnRender      = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeFD               = 0xD00,
-    FeatureTypeFLD              = 0xE00,
-    FeatureTypeFB               = 0xF00,
-    FeatureTypeSecureCopy       = 0x1000,
-    FeatureTypeSecureCopyOnRender = FeatureTypeSecureCopy | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeSR               = 0x1100,
-    FeatureTypeSROnVebox        = FeatureTypeSR | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeSROnRender       = FeatureTypeSR | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeLace             = 0x1200,
-    FeatureTypeLaceOnVebox      = FeatureTypeLace | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeLaceOnRender     = FeatureTypeLace | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeGamutExt         = 0x1300,
-    FeatureTypeDV               = 0x1400,
-    FeatureTypeDVOnVebox        = FeatureTypeDV | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeFc               = 0x1500,
-    FeatureTypeFcOnRender       = FeatureTypeFc | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeLumakey          = 0x1600,
-    FeatureTypeLumakeyOnRender  = FeatureTypeLumakey | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeBlending         = 0x1700,
-    FeatureTypeBlendingOnRender = FeatureTypeBlending | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeColorFill        = 0x1800,
-    FeatureTypeColorFillOnSfc   = FeatureTypeColorFill | FEATURE_TYPE_ENGINE_BITS_SFC,
-    FeatureTypeColorFillOnRender = FeatureTypeColorFill | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeAlpha            = 0x1900,
-    FeatureTypeAlphaOnSfc       = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_SFC,
-    FeatureTypeAlphaOnVebox     = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeAlphaOnRender    = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeCappipe          = 0x2000,
-    FeatureTypeCappipeOnVebox   = FeatureTypeCappipe | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeCappipeOnRender  = FeatureTypeCappipe | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeFDFB             = 0x2100,
-    FeatureTypeFDFBOnVebox      = FeatureTypeFDFB | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeFDFBOnRender     = FeatureTypeFDFB | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeSegmentation     = 0x2200,
-    FeatureTypeSegmentationOnVebox  = FeatureTypeSegmentation | FEATURE_TYPE_ENGINE_BITS_VEBOX,
-    FeatureTypeSegmentationOnRender = FeatureTypeSegmentation | FEATURE_TYPE_ENGINE_BITS_RENDER,
-    FeatureTypeS3D                  = 0x2300,
-    // ...
+    FeatureTypeInvalid              = 0,
+    FeatureTypeCsc                  = 0x100,
+    FeatureTypeCscOnSfc             = FeatureTypeCsc | FEATURE_TYPE_ENGINE_BITS_SFC,
+    FeatureTypeCscOnVebox           = FeatureTypeCsc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeCscOnRender          = FeatureTypeCsc | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeRotMir               = 0x200,
+    FeatureTypeRotMirOnSfc          = FeatureTypeRotMir | FEATURE_TYPE_ENGINE_BITS_SFC,
+    FeatureTypeRotMirOnRender       = FeatureTypeRotMir | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeScaling              = 0x300,
+    FeatureTypeScalingOnSfc         = FeatureTypeScaling | FEATURE_TYPE_ENGINE_BITS_SFC,
+    FeatureTypeScalingOnRender      = FeatureTypeScaling | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeDn                   = 0x400,
+    FeatureTypeDnOnVebox            = FeatureTypeDn | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeDnHVSCalOnRender     = FeatureTypeDn | FEATURE_TYPE_ENGINE_BITS_RENDER | FEATURE_TYPE_ENGINE_BITS_SUB_STEP,
+    FeatureTypeDi                   = 0x500,
+    FeatureTypeDiOnVebox            = FeatureTypeDi | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeDiOnRender           = FeatureTypeDi | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeSte                  = 0x600,
+    FeatureTypeSteOnVebox           = FeatureTypeSte | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeVeboxUpdate          = 0x700,
+    FeatureTypeVeboxUpdateOnRender  = FeatureTypeVeboxUpdate | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeTcc                  = 0x800,
+    FeatureTypeTccOnVebox           = FeatureTypeTcc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeProcamp              = 0x900,
+    FeatureTypeProcampOnVebox       = FeatureTypeProcamp | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeProcampOnRender      = FeatureTypeProcamp | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeCgc                  = 0xA00,
+    FeatureTypeCgcOnVebox           = FeatureTypeCgc | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeHdr                  = 0xB00,
+    FeatureTypeHdrOnVebox           = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeHdr3DLutCalOnRender  = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_RENDER | FEATURE_TYPE_ENGINE_BITS_SUB_STEP,
+    FeatureTypeHdrOnRender          = FeatureTypeHdr | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeSecureCopy           = 0xC00,
+    FeatureTypeSecureCopyOnRender   = FeatureTypeSecureCopy | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeGamutExt             = 0xD00,
+    FeatureTypeFc                   = 0xE00,
+    FeatureTypeFcOnRender           = FeatureTypeFc | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeLumakey              = 0xF00,
+    FeatureTypeLumakeyOnRender      = FeatureTypeLumakey | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeBlending             = 0x1000,
+    FeatureTypeBlendingOnRender     = FeatureTypeBlending | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeColorFill            = 0x1100,
+    FeatureTypeColorFillOnSfc       = FeatureTypeColorFill | FEATURE_TYPE_ENGINE_BITS_SFC,
+    FeatureTypeColorFillOnRender    = FeatureTypeColorFill | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    FeatureTypeAlpha                = 0x1200,
+    FeatureTypeAlphaOnSfc           = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_SFC,
+    FeatureTypeAlphaOnVebox         = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_VEBOX,
+    FeatureTypeAlphaOnRender        = FeatureTypeAlpha | FEATURE_TYPE_ENGINE_BITS_RENDER,
+    NumOfFeatureTypeBase,
+
+#ifdef _MEDIA_RESERVED
+#include "feature_type_ext.h"
+#endif
+
     NumOfFeatureType
 };
 
@@ -158,598 +131,6 @@ enum RenderTargetType
     RenderTargetTypeParameter
 };
 
-enum SurfaceType
-{
-    SurfaceTypeInvalid = 0,
-    SurfaceTypeVeboxInput,
-    SurfaceTypeVeboxPreviousInput,
-    SurfaceTypeDNOutput,
-    SurfaceTypeVeboxCurrentOutput,
-    SurfaceTypeVeboxPreviousOutput,
-    SurfaceTypeScalar,
-    SurfaceTypeSTMMIn,
-    SurfaceTypeSTMMOut,
-    SurfaceTypeACEHistory,
-    SurfaceTypeFMDHistory,
-    SurfaceTypeLaceAceRGBHistogram,
-    SurfaceTypeLaceLut,
-    SurfaceTypeStatistics,
-    SurfaceTypeSkinScore,
-    SurfaceType3DLut,
-    SurfaceType1k1dLut,
-    SurfaceType1dLutHDR,
-    SurfaceTypeAlphaOrVignette,
-    SurfaceTypeVeboxStateHeap_Drv,
-    SurfaceTypeVeboxStateHeap_Knr,
-    SurfaceTypeAutoDNNoiseLevel, // with kernel path needed
-    SurfaceTypeAutoDNSpatialConfig,
-    SurfaceTypeRenderInput,
-    SurfaceTypeRenderOutput,
-    SurfaceTypeRenderSRInput, //Super Resolution related Surface and Buffer index Reserved
-    SurfaceTypeRenderSRPreCSCInput,
-    SurfaceTypeRenderSRBuffer = SurfaceTypeRenderSRPreCSCInput + 0x100,
-    SurfaceTypeRenderSRMax = SurfaceTypeRenderSRBuffer + 0x100,
-    SurfaceTypeAggregatedHistogram,
-    SurfaceTypeFrameHistogram,
-    SurfaceTypeStdStatistics,
-    SurfaceTypePwlfIn,
-    SurfaceTypePwlfOut,
-    SurfaceTypeWeitCoef,
-    SurfaceTypGlobalToneMappingCurveLUT,
-    // FC
-    SurfaceTypeFcInputLayer0,
-    SurfaceTypeFcInputLayer1,
-    SurfaceTypeFcInputLayer2,
-    SurfaceTypeFcInputLayer3,
-    SurfaceTypeFcInputLayer4,
-    SurfaceTypeFcInputLayer5,
-    SurfaceTypeFcInputLayer6,
-    SurfaceTypeFcInputLayer7,
-    SurfaceTypeFcInputLayerMax = SurfaceTypeFcInputLayer7,
-    SurfaceTypeFcInputLayer0Field1Dual,
-    SurfaceTypeFcInputLayer1Field1Dual,
-    SurfaceTypeFcInputLayer2Field1Dual,
-    SurfaceTypeFcInputLayer3Field1Dual,
-    SurfaceTypeFcInputLayer4Field1Dual,
-    SurfaceTypeFcInputLayer5Field1Dual,
-    SurfaceTypeFcInputLayer6Field1Dual,
-    SurfaceTypeFcInputLayer7Field1Dual,
-    SurfaceTypeFcInputLayerMaxField1Dual = SurfaceTypeFcInputLayer7Field1Dual,
-    SurfaceTypeFcTarget0,
-    SurfaceTypeFcTarget1,
-    SurfaceTypeFcCscCoeff,
-    SurfaceTypeDecompressionSync,
-    // LGCA related Surfaces
-    SurfaceTypeSamplerSurfaceR,
-    SurfaceTypeSamplerSurfaceG,
-    SurfaceTypeSamplerSurfaceB,
-    SurfaceTypeOutputSurfaceR,
-    SurfaceTypeOutputSurfaceG,
-    SurfaceTypeOutputSurfaceB,
-    SurfaceTypeSamplerParamsMinMax,
-    // 3DLut Kernel
-    SurfaceType3DLut2D,
-    SurfaceType3DLutCoef,
-    // FDFB
-    SurfaceTypeFDFBSrcHandle,
-    SurfaceTypeFDFBOutFaceBuffer,
-    SurfaceTypeFDFBOutFaceCountBuffer,
-    SurfaceTypeFDFBOutFaceViewBuffer,
-    SurfaceTypeFDFBFrameCount,
-    SurfaceTypeFDFBFaceFlag,
-    SurfaceTypeFDFBValidatorFlag,
-    SurfaceTypeFDFBSkipFB,
-    SurfaceTypeFDFBConfidenceOut,
-    SurfaceTypeFDFBExitFlag,
-    SurfaceTypeFDFBFDExitFlag,
-    SurfaceTypeFDFBStrength2,
-    SurfaceTypeFDFBRemappedLM,
-    SurfaceTypeFDFBPostProcessingOutCur,
-    SurfaceTypeFDFBPreFaceCountBuffer,
-    //FD
-    SurfaceTypeFDLutListBuffer,
-    SurfaceTypeFDLutListBuffer2,
-    SurfaceTypeFDLutListBuffer3,
-    SurfaceTypeFDLutListBuffer4,
-    SurfaceTypeFDLutListBuffer5,
-    SurfaceTypeFDLutListBuffer6,
-    SurfaceTypeFDLutListBuffer7,
-    SurfaceTypeFDLutListBuffer8,
-    SurfaceTypeFDLutListBuffer9,
-    SurfaceTypeFDLutListBuffer10,
-    SurfaceTypeFDLutListBuffer11,
-    SurfaceTypeFDLutListBuffer12,
-    SurfaceTypeFDLutListBuffer13,
-    SurfaceTypeFDLutListBuffer14,
-    SurfaceTypeFDLutListBuffer15,
-    SurfaceTypeFDLutListBuffer16,
-    SurfaceTypeFDLutListBuffer17,
-    SurfaceTypeFDLutListBuffer18,
-    SurfaceTypeFDLutListBuffer19,
-    SurfaceTypeFDLutListBuffer20,
-    SurfaceTypeFDLutListBuffer21,
-    SurfaceTypeFDLutListBuffer22,
-    SurfaceTypeFDLutListBuffer23,
-    SurfaceTypeFDLutListBuffer24,
-    SurfaceTypeFDLutListBuffer25,
-    SurfaceTypeFDLutListBuffer26,
-    SurfaceTypeFDLutListBuffer27,
-    SurfaceTypeFDLutListBuffer28,
-    SurfaceTypeFDLutListBuffer29,
-    SurfaceTypeFDLutListBuffer30,
-    SurfaceTypeFDLutListBuffer31,
-    SurfaceTypeFDLutListBuffer32,
-    SurfaceTypeFDLutListBuffer33,
-    SurfaceTypeFDLutListBuffer34,
-    SurfaceTypeFDLutListBuffer35,
-    SurfaceTypeFDLutListBuffer36,
-    SurfaceTypeFDLutListBuffer37,
-    SurfaceTypeFDLutListBuffer38,
-    SurfaceTypeFDLutListBuffer39,
-    SurfaceTypeFDLutListBuffer40,
-    SurfaceTypeFDLutListBuffer41,
-    SurfaceTypeFDLutListBuffer42,
-    SurfaceTypeFDLutListBuffer43,
-    SurfaceTypeFDLutListBuffer44,
-    SurfaceTypeFDLutListBuffer45,
-    SurfaceTypeFDLutListBuffer46,
-    SurfaceTypeFDLutListBuffer47,
-    SurfaceTypeFDLutListBuffer48,
-    SurfaceTypeFDLutListBuffer49,
-    SurfaceTypeFDLutListBuffer50,
-    SurfaceTypeFDLutListBuffer51,
-    SurfaceTypeFDLutListBuffer52,
-    SurfaceTypeFDLutListBuffer53,
-    SurfaceTypeFDLutListBuffer54,
-    SurfaceTypeFDLutListBuffer55,
-    SurfaceTypeFDLutListBuffer56,
-    SurfaceTypeFDLutListBuffer57,
-    SurfaceTypeFDLutListBuffer58,
-    SurfaceTypeFDLutListBuffer59,
-    SurfaceTypeFDLutListBuffer60,
-    SurfaceTypeFDLutListBuffer61,
-    SurfaceTypeFDLutListBuffer62,
-    SurfaceTypeFDLutListBuffer63,
-    SurfaceTypeFDLutListBuffer64,
-    SurfaceTypeFDLutCounterBuffer,
-    SurfaceTypeFDLutCounterBuffer2,
-    SurfaceTypeFDLutCounterBuffer3,
-    SurfaceTypeFDLutCounterBuffer4,
-    SurfaceTypeFDLutCounterBuffer5,
-    SurfaceTypeFDLutCounterBuffer6,
-    SurfaceTypeFDLutCounterBuffer7,
-    SurfaceTypeFDLutCounterBuffer8,
-    SurfaceTypeFDLutCounterBuffer9,
-    SurfaceTypeFDLutCounterBuffer10,
-    SurfaceTypeFDLutCounterBuffer11,
-    SurfaceTypeFDLutCounterBuffer12,
-    SurfaceTypeFDLutCounterBuffer13,
-    SurfaceTypeFDLutCounterBuffer14,
-    SurfaceTypeFDLutCounterBuffer15,
-    SurfaceTypeFDLutCounterBuffer16,
-    SurfaceTypeFDLutCounterBuffer17,
-    SurfaceTypeFDLutCounterBuffer18,
-    SurfaceTypeFDLutCounterBuffer19,
-    SurfaceTypeFDLutCounterBuffer20,
-    SurfaceTypeFDLutCounterBuffer21,
-    SurfaceTypeFDLutCounterBuffer22,
-    SurfaceTypeFDLutCounterBuffer23,
-    SurfaceTypeFDLutCounterBuffer24,
-    SurfaceTypeFDLutCounterBuffer25,
-    SurfaceTypeFDLutCounterBuffer26,
-    SurfaceTypeFDLutCounterBuffer27,
-    SurfaceTypeFDLutCounterBuffer28,
-    SurfaceTypeFDLutCounterBuffer29,
-    SurfaceTypeFDLutCounterBuffer30,
-    SurfaceTypeFDLutCounterBuffer31,
-    SurfaceTypeFDLutCounterBuffer32,
-    SurfaceTypeFDLutCounterBuffer33,
-    SurfaceTypeFDLutCounterBuffer34,
-    SurfaceTypeFDLutCounterBuffer35,
-    SurfaceTypeFDLutCounterBuffer36,
-    SurfaceTypeFDLutCounterBuffer37,
-    SurfaceTypeFDLutCounterBuffer38,
-    SurfaceTypeFDLutCounterBuffer39,
-    SurfaceTypeFDLutCounterBuffer40,
-    SurfaceTypeFDLutCounterBuffer41,
-    SurfaceTypeFDLutCounterBuffer42,
-    SurfaceTypeFDLutCounterBuffer43,
-    SurfaceTypeFDLutCounterBuffer44,
-    SurfaceTypeFDLutCounterBuffer45,
-    SurfaceTypeFDLutCounterBuffer46,
-    SurfaceTypeFDLutCounterBuffer47,
-    SurfaceTypeFDLutCounterBuffer48,
-    SurfaceTypeFDLutCounterBuffer49,
-    SurfaceTypeFDLutCounterBuffer50,
-    SurfaceTypeFDLutCounterBuffer51,
-    SurfaceTypeFDLutCounterBuffer52,
-    SurfaceTypeFDLutCounterBuffer53,
-    SurfaceTypeFDLutCounterBuffer54,
-    SurfaceTypeFDLutCounterBuffer55,
-    SurfaceTypeFDLutCounterBuffer56,
-    SurfaceTypeFDLutCounterBuffer57,
-    SurfaceTypeFDLutCounterBuffer58,
-    SurfaceTypeFDLutCounterBuffer59,
-    SurfaceTypeFDLutCounterBuffer60,
-    SurfaceTypeFDLutCounterBuffer61,
-    SurfaceTypeFDLutCounterBuffer62,
-    SurfaceTypeFDLutCounterBuffer63,
-    SurfaceTypeFDLutCounterBuffer64,
-    SurfaceTypeFDFaceListBuffer,
-    SurfaceTypeFDFaceListBuffer2,
-    SurfaceTypeFDFaceListBuffer3,
-    SurfaceTypeFDFaceListBuffer4,
-    SurfaceTypeFDFaceListBuffer5,
-    SurfaceTypeFDFaceCounterBuffer,
-    SurfaceTypeFDFaceCounterBuffer2,
-    SurfaceTypeFDFaceCounterBuffer3,
-    SurfaceTypeFDFaceCounterBuffer4,
-    SurfaceTypeFDFaceCounterBuffer5,
-    SurfaceTypeFDLutIntHandle,
-    SurfaceTypeFDLutIntHandle2,
-    SurfaceTypeFDLutIntHandle3,
-    SurfaceTypeFDLutIntHandle4,
-    SurfaceTypeFDLutIntHandle5,
-    SurfaceTypeFDCoordnateHandle,
-    SurfaceTypeFDCoordnateHandle2,
-    SurfaceTypeFDCoordnateHandle3,
-    SurfaceTypeFDCoordnateHandle4,
-    SurfaceTypeFDCoordnateHandle5,
-    SurfaceTypeFDRoundsHandle,
-    SurfaceTypeFDRoundsHandle2,
-    SurfaceTypeFDRoundsHandle3,
-    SurfaceTypeFDRoundsHandle4,
-    SurfaceTypeFDRoundsHandle5,
-    SurfaceTypeFDThresholdHandle,
-    SurfaceTypeFDThresholdHandle2,
-    SurfaceTypeFDThresholdHandle3,
-    SurfaceTypeFDThresholdHandle4,
-    SurfaceTypeFDThresholdHandle5,
-    SurfaceTypeFDFaceGroupCountBuffer,
-    SurfaceTypeFDFaceGroupCountBuffer2,
-    SurfaceTypeFDFaceGroupCountBuffer3,
-    SurfaceTypeFDFaceGroupCountBuffer4,
-    SurfaceTypeFDFaceGroupCountBuffer5,
-    SurfaceTypeFDFaceGroupBuffer,
-    SurfaceTypeFDFaceGroupBuffer2,
-    SurfaceTypeFDFaceGroupBuffer3,
-    SurfaceTypeFDFaceGroupBuffer4,
-    SurfaceTypeFDFaceGroupBuffer5,
-    SurfaceTypeFDOutFaceBuffer,
-    SurfaceTypeFDOutFaceCountBuffer,
-    SurfaceTypeFDOutFaceViewBuffer,
-    SurfaceTypeFDFrameCount,
-    SurfaceTypeFDFaceFlag,
-    SurfaceTypeFDValidatorFlag,
-    SurfaceTypeFDConfidenceOut,
-    SurfaceTypeFDPostProcessingOutCur,
-    SurfaceTypeFDPreFaceCountBuffer,
-    SurfaceTypeFDScaleHandle,
-    SurfaceTypeFDScaleHandle2,
-    SurfaceTypeFDScaleHandle3,
-    SurfaceTypeFDScaleHandle4,
-    SurfaceTypeFDScaleHandle5,
-    SurfaceTypeFDScaleHandle6,
-    SurfaceTypeFDScaleHandle7,
-    SurfaceTypeFDScaleHandle8,
-    SurfaceTypeFDScaleHandle9,
-    SurfaceTypeFDScaleHandle10,
-    SurfaceTypeFDScaleHandle11,
-    SurfaceTypeFDScaleHandle12,
-    SurfaceTypeFDScaleHandle13,
-    SurfaceTypeFDScaleHandle14,
-    SurfaceTypeFDScaleHandle15,
-    SurfaceTypeFDScaleHandle16,
-    SurfaceTypeFDScaleHandle17,
-    SurfaceTypeFDScaleHandle18,
-    SurfaceTypeFDScaleHandle19,
-    SurfaceTypeFDScaleHandle20,
-    SurfaceTypeFDScaleHandle21,
-    SurfaceTypeFDScaleHandle22,
-    SurfaceTypeFDScaleHandle23,
-    SurfaceTypeFDScaleHandle24,
-    SurfaceTypeFDScaleHandle25,
-    SurfaceTypeFDScaleHandle26,
-    SurfaceTypeFDScaleHandle27,
-    SurfaceTypeFDScaleHandle28,
-    SurfaceTypeFDScaleHandle29,
-    SurfaceTypeFDScaleHandle30,
-    SurfaceTypeFDScaleHandle31,
-    SurfaceTypeFDScaleHandle32,
-    SurfaceTypeFDScaleHandle33,
-    SurfaceTypeFDScaleHandle34,
-    SurfaceTypeFDScaleHandle35,
-    SurfaceTypeFDScaleHandle36,
-    SurfaceTypeFDScaleHandle37,
-    SurfaceTypeFDScaleHandle38,
-    SurfaceTypeFDScaleHandle39,
-    SurfaceTypeFDScaleHandle40,
-    SurfaceTypeFDScaleHandle41,
-    SurfaceTypeFDScaleHandle42,
-    SurfaceTypeFDScaleHandle43,
-    SurfaceTypeFDScaleHandle44,
-    SurfaceTypeFDScaleHandle45,
-    SurfaceTypeFDScaleHandle46,
-    SurfaceTypeFDScaleHandle47,
-    SurfaceTypeFDScaleHandle48,
-    SurfaceTypeFDScaleHandle49,
-    SurfaceTypeFDScaleHandle50,
-    SurfaceTypeFDScaleHandle51,
-    SurfaceTypeFDScaleHandle52,
-    SurfaceTypeFDScaleHandle53,
-    SurfaceTypeFDScaleHandle54,
-    SurfaceTypeFDScaleHandle55,
-    SurfaceTypeFDScaleHandle56,
-    SurfaceTypeFDScaleHandle57,
-    SurfaceTypeFDScaleHandle58,
-    SurfaceTypeFDScaleHandle59,
-    SurfaceTypeFDScaleHandle60,
-    SurfaceTypeFDScaleHandle61,
-    SurfaceTypeFDScaleHandle62,
-    SurfaceTypeFDScaleHandle63,
-    SurfaceTypeFDScaleHandle64,
-    SurfaceTypeFDMLbpHandle,
-    SurfaceTypeFDMLbpHandle2,
-    SurfaceTypeFDMLbpHandle3,
-    SurfaceTypeFDMLbpHandle4,
-    SurfaceTypeFDMLbpHandle5,
-    SurfaceTypeFDMLbpHandle6,
-    SurfaceTypeFDMLbpHandle7,
-    SurfaceTypeFDMLbpHandle8,
-    SurfaceTypeFDMLbpHandle9,
-    SurfaceTypeFDMLbpHandle10,
-    SurfaceTypeFDMLbpHandle11,
-    SurfaceTypeFDMLbpHandle12,
-    SurfaceTypeFDMLbpHandle13,
-    SurfaceTypeFDMLbpHandle14,
-    SurfaceTypeFDMLbpHandle15,
-    SurfaceTypeFDMLbpHandle16,
-    SurfaceTypeFDMLbpHandle17,
-    SurfaceTypeFDMLbpHandle18,
-    SurfaceTypeFDMLbpHandle19,
-    SurfaceTypeFDMLbpHandle20,
-    SurfaceTypeFDMLbpHandle21,
-    SurfaceTypeFDMLbpHandle22,
-    SurfaceTypeFDMLbpHandle23,
-    SurfaceTypeFDMLbpHandle24,
-    SurfaceTypeFDMLbpHandle25,
-    SurfaceTypeFDMLbpHandle26,
-    SurfaceTypeFDMLbpHandle27,
-    SurfaceTypeFDMLbpHandle28,
-    SurfaceTypeFDMLbpHandle29,
-    SurfaceTypeFDMLbpHandle30,
-    SurfaceTypeFDMLbpHandle31,
-    SurfaceTypeFDMLbpHandle32,
-    SurfaceTypeFDMLbpHandle33,
-    SurfaceTypeFDMLbpHandle34,
-    SurfaceTypeFDMLbpHandle35,
-    SurfaceTypeFDMLbpHandle36,
-    SurfaceTypeFDMLbpHandle37,
-    SurfaceTypeFDMLbpHandle38,
-    SurfaceTypeFDMLbpHandle39,
-    SurfaceTypeFDMLbpHandle40,
-    SurfaceTypeFDMLbpHandle41,
-    SurfaceTypeFDMLbpHandle42,
-    SurfaceTypeFDMLbpHandle43,
-    SurfaceTypeFDMLbpHandle44,
-    SurfaceTypeFDMLbpHandle45,
-    SurfaceTypeFDMLbpHandle46,
-    SurfaceTypeFDMLbpHandle47,
-    SurfaceTypeFDMLbpHandle48,
-    SurfaceTypeFDMLbpHandle49,
-    SurfaceTypeFDMLbpHandle50,
-    SurfaceTypeFDMLbpHandle51,
-    SurfaceTypeFDMLbpHandle52,
-    SurfaceTypeFDMLbpHandle53,
-    SurfaceTypeFDMLbpHandle54,
-    SurfaceTypeFDMLbpHandle55,
-    SurfaceTypeFDMLbpHandle56,
-    SurfaceTypeFDMLbpHandle57,
-    SurfaceTypeFDMLbpHandle58,
-    SurfaceTypeFDMLbpHandle59,
-    SurfaceTypeFDMLbpHandle60,
-    SurfaceTypeFDMLbpHandle61,
-    SurfaceTypeFDMLbpHandle62,
-    SurfaceTypeFDMLbpHandle63,
-    SurfaceTypeFDMLbpHandle64,
-    // FLD
-//    SurfaceTypeFLDFrameCount,
-    SurfaceTypeFLDValidatorFlag,
-    SurfaceTypeFLDGlobalFlag,
-    SurfaceTypeFLDSurfaceSrc,
-    SurfaceTypeFLDResizeImageOutIn,
-    SurfaceTypeFLDGaussianWeightOutIn,
-    SurfaceTypeFLDFeaturesOutIn,
-    SurfaceTypeFLDLandmarkInOut,
-    SurfaceTypeFLDGlobalSumOutIn,
-    SurfaceTypeFLDCoefficientIn,
-    SurfaceTypeFLDMeanShapeInOut,
-    SurfaceTypeFLDEyeMeanShape,
-    SurfaceTypeFLDEyeLandmarks,
-    SurfaceTypeFLDInvAffineMatrix,
-    SurfaceTypeFLDEyeCoefficientIn,
-    SurfaceTypeFLDRemappedLM,
-    SurfaceTypeFLDEFFilteredLMK,
-    SurfaceTypeFLDPostProcessingOutInPre,
-    SurfaceTypeFLDPreProcessingIn,
-    SurfaceTypeFLDScoreboarGetSum,
-    SurfaceTypeFLDScoreboarExtractFeature,
-    SurfaceTypeFLDThreadMapGetSum,
-    SurfaceTypeFLDThreadMapExtractFeature,
-    SurfaceTypeFLDScaleOutIn,
-    SurfaceTypeFLDFlagOutIn,
-    SurfaceTypeFLDStartOutIn,
-    SurfaceTypeFLDNormalizeOut,
-    SurfaceTypeFLDNormalizeCoeff,
-    SurfaceTypeFLDMlbpOut,
-    SurfaceTypeFLDGetsumCoeffX,
-    SurfaceTypeFLDGetsumCoeffY,
-    SurfaceTypeFLDGetsumCoeffH,
-    SurfaceTypeFLDFaceModel,
-    // FB
-    SurfaceTypeFBSurfaceSrc,
-    SurfaceTypeFBSurface1,
-    SurfaceTypeFBSurface2,
-    SurfaceTypeFBSurface3,
-    SurfaceTypeFBSurfaceTempY,
-    SurfaceTypeFBSurfaceTempUV,
-    SurfaceTypeFBSurfaceTempTposedY,
-    SurfaceTypeFBSurfaceTempTposedUV,
-    SurfaceTypeFBMask1,
-    SurfaceTypeFBMask2,
-    SurfaceTypeFBFaceMask,
-    SurfaceTypeFBFaceMask2x,
-    SurfaceTypeFBFaceMask4x,
-    SurfaceTypeFBLipMaskInput,
-    SurfaceTypeFBLipMaskOutput,
-    SurfaceTypeFBLipPosition,
-    SurfaceTypeFBLipPosition2,
-    SurfaceTypeFBLipSum,
-    SurfaceTypeFBLipMax,
-    SurfaceTypeFBLipMin,
-    SurfaceTypeFBSamplerOut,
-    SurfaceTypeFBSamplerOut1,
-    SurfaceTypeFBSTDFrameCount,
-    SurfaceTypeFBSTDSamples,
-    SurfaceTypeFBSTDHistogram,
-    SurfaceTypeFBSTDHistory,
-    SurfaceTypeFBEyeModelMeta,
-    SurfaceTypeFBEyeModelDatas,
-    SurfaceTypeFBEyeModelDatas2,
-    SurfaceTypeFBEyeModelDatas3,
-    SurfaceTypeFBEyeModelDatas4,
-    SurfaceTypeFBEyeModelDatas5,
-    SurfaceTypeFBEyeModelDatas6,
-    SurfaceTypeFBEyeModelDatas7,
-    SurfaceTypeFBEyeModelDatas8,
-    SurfaceTypeFBEyeModelDatas9,
-    SurfaceTypeFBEyeModelDatas10,
-    SurfaceTypeFBEyeAffineMatrix,
-    SurfaceTypeFBEyeFeatureFlag,
-    SurfaceTypeFBEyeParams,
-    SurfaceTypeFBEyeRMap,
-    SurfaceTypeFBEyeCoMap,
-    SurfaceTypeFBBrightenMask,
-    SurfaceTypeFBEyeCurve,
-    SurfaceTypeFBShadowMask1,
-    SurfaceTypeFBShadowMask2,
-    SurfaceTypeFBPupilMask,
-    SurfaceTypeFBPupilParamSurf,
-    SurfaceTypeFBPupilHistSurf,
-    SurfaceTypeFBPupilVerSurf,
-    SurfaceTypeFBPupilHorSurf,
-    SurfaceTypeFBTeethColorMap,
-    SurfaceTypeFBSurfacesForVeBox,
-    SurfaceTypeFBSurfacesForVeBox1,
-    SurfaceTypeFBSurfacesForVeBox2,
-    SurfaceTypeFBVeboxParamBuf,
-    SurfaceTypeFBFacialRegions,
-    SurfaceTypeFBPostProcessingOutCur,
-    SurfaceTypeFBRemappedLM,
-    SurfaceTypeFBSamplerIndex,
-    SurfaceTypeFBInputSampler,
-    // HVS Kernel
-    SurfaceTypeHVSTable,
-    //Segmentation
-    SurfaceTypeSegRenderPreviousInput,
-    SurfaceTypeSegRenderTempOutput, //Used for seg out only
-    SurfaceTypeSegColorBalanceInput,
-    SurfaceTypeSegBackground,
-    SurfaceTypeSegGaussianCoeffBuffer,
-    SurfaceTypeSegTFMask,
-    SurfaceTypeSegTFOutMask,
-    SurfaceTypeSegWindowSize,
-    SurfaceTypeSegMaskThreshold,
-    SurfaceTypeSegMaskScaling,
-    SurfaceTypeSegMaskBlur,
-    SurfaceTypeSegBlurScaling,
-    SurfaceTypeSegGaussianBlur,
-    SurfaceTypeSegBlur,
-    SurfaceTypeSegBlur2,
-    SurfaceTypeSegBlur3,
-    SurfaceTypeSegGFLayer,
-    SurfaceTypeSegGFLayerEnd = SurfaceTypeSegGFLayer + GFSURFACE_COUNT,
-    SurfaceTypeSegGFOut,
-    SurfaceTypeSegGFOut2,
-    SurfaceTypeSegGFOut3,
-    SurfaceTypeSegGFOut4,
-    SurfaceTypeSegInputMotion,
-    SurfaceTypeSegInputMotionEnd = SurfaceTypeSegInputMotion + MOTION_CHANNEL - 1,
-    SurfaceTypeSegPreInputMotion,
-    SurfaceTypeSegPreInputMotionEnd = SurfaceTypeSegPreInputMotion + MOTION_CHANNEL - 1,
-    SurfaceTypeSegDiffMotion,
-    SurfaceTypeSegDiffMotionEnd = SurfaceTypeSegDiffMotion + MOTION_CHANNEL - 1,
-    SurfaceTypeSegErode1x2Motion,
-    SurfaceTypeSegErode1x2MotionEnd = SurfaceTypeSegErode1x2Motion + MOTION_CHANNEL - 1,
-    SurfaceTypeSegErode2x1Motion,
-    SurfaceTypeSegErode2x1Motion2,
-    SurfaceTypeSegErode2x1Motion3,
-    SurfaceTypeSegSumMotion,
-    SurfaceTypeSegRemoveBlob,
-    SurfaceTypeSegColorBalance,
-    // Segmentation layers
-    SurfaceTypeSegModelLayer,
-    SurfaceTypeSegModelLayerEnd = SurfaceTypeSegModelLayer + MAX_MODELSURFACE_COUNT,
-    SurfaceTypeSegWeights,
-    SurfaceTypeSegWeightsEnd = SurfaceTypeSegWeights + MAX_MODELSURFACE_COUNT,
-    SurfaceTypeSegBias,
-    SurfaceTypeSegBiasEnd = SurfaceTypeSegBias + MAX_MODELSURFACE_COUNT,
-
-    // SR
-    SurfaceTypeSRLumaInputSurf,
-    SurfaceTypeSRTempLumaOutput,
-    SurfaceTypeSRTempLumaOutputEnd = SurfaceTypeSRTempLumaOutput + SURFACETYPE_SIZE32,
-    SurfaceTypeSRTempLuma2Output,
-    SurfaceTypeSRTempLuma2OutputEnd = SurfaceTypeSRTempLuma2Output + SURFACETYPE_SIZE16,
-    SurfaceTypeSRTempLuma3Output,
-    SurfaceTypeSRTempLuma3OutputEnd = SurfaceTypeSRTempLuma3Output + SURFACETYPE_SIZE5,
-    SurfaceTypeSRTempLuma4Output,
-    SurfaceTypeSRTempLuma4OutputEnd = SurfaceTypeSRTempLuma4Output + SURFACETYPE_SIZE32,
-    SurfaceTypeSRTempLuma5Output,
-    SurfaceTypeSRWeightBuffer,
-    SurfaceTypeSRWeightBufferEnd = SurfaceTypeSRWeightBuffer + SURFACETYPE_SIZE10,
-    SurfaceTypeSRBiasBuffer,
-    SurfaceTypeSRBiasBufferEnd = SurfaceTypeSRBiasBuffer + SURFACETYPE_SIZE10,
-    SurfaceTypeSRPreluBuffer,
-    SurfaceTypeSRPreluBufferEnd = SurfaceTypeSRPreluBuffer + SURFACETYPE_SIZE10,
-    SurfaceTypeSRSlopeBuffer,
-    SurfaceTypeSRSlopeBufferEnd = SurfaceTypeSRSlopeBuffer + SURFACETYPE_SIZE5,
-    SurfaceTypeSROutput,
-    SurfaceTypeSRChromaInput,
-
-    // HDR Kernel
-    SurfaceTypeHdrInputLayer0,
-    SurfaceTypeHdrInputLayer1,
-    SurfaceTypeHdrInputLayer2,
-    SurfaceTypeHdrInputLayer3,
-    SurfaceTypeHdrInputLayer4,
-    SurfaceTypeHdrInputLayer5,
-    SurfaceTypeHdrInputLayer6,
-    SurfaceTypeHdrInputLayer7,
-    SurfaceTypeHdrInputLayerMax = SurfaceTypeHdrInputLayer7,
-    SurfaceTypeHdrOETF1DLUTSurface0,
-    SurfaceTypeHdrOETF1DLUTSurface1,
-    SurfaceTypeHdrOETF1DLUTSurface2,
-    SurfaceTypeHdrOETF1DLUTSurface3,
-    SurfaceTypeHdrOETF1DLUTSurface4,
-    SurfaceTypeHdrOETF1DLUTSurface5,
-    SurfaceTypeHdrOETF1DLUTSurface6,
-    SurfaceTypeHdrOETF1DLUTSurface7,
-    SurfaceTypeHdrCRI3DLUTSurface0,
-    SurfaceTypeHdrCRI3DLUTSurface1,
-    SurfaceTypeHdrCRI3DLUTSurface2,
-    SurfaceTypeHdrCRI3DLUTSurface3,
-    SurfaceTypeHdrCRI3DLUTSurface4,
-    SurfaceTypeHdrCRI3DLUTSurface5,
-    SurfaceTypeHdrCRI3DLUTSurface6,
-    SurfaceTypeHdrCRI3DLUTSurface7,
-    SurfaceTypeHdrTarget0,
-    SurfaceTypeHdrCoeff,
-    SurfaceTypeHdrAutoModeCoeff,
-    SurfaceTypeHdrAutoModeIirTempSurface,
-    NumberOfSurfaceType
-};
-
 using  VP_SURFACE_GROUP = std::map<SurfaceType, VP_SURFACE*>;
 
 enum OutMode
@@ -1024,6 +405,7 @@ struct FeatureParamCsc : public FeatureParam
     PVPHAL_ALPHA_PARAMS pAlphaParams    = nullptr;
     MOS_FORMAT          formatforCUS    = Format_None;            //!< Only valid when formatforCUS != Format_None for Chromaupsampling. To be cleared in SwFilterCsc::Configure
     FeatureParamCsc     *next           = nullptr;                //!< pointe to new/next generated CSC params
+    bool                isFullRgbG10P709 = false;                  //!< whether output colorspace is DXGI_COLOR_SPACE_RGB_FULL_G10_NONE_P709
 };
 
 class SwFilterCsc : public SwFilter
@@ -1269,7 +651,6 @@ struct FeatureParamDeinterlace : public FeatureParam
     bool                    bHDContent           = false;
     PVPHAL_DI_PARAMS        diParams             = nullptr;
     bool                    bFmdExtraVariance    = false;     //!< Check if extra FMD variances need to be calculated
-    bool                    bFmdKernelEnable     = false;     //!< FMD kernel path enabled
     bool                    bQueryVarianceEnable = false;     //!< Query variance enabled
     uint32_t                heightInput          = 0;
     RECT                    rcSrc                = {0, 0, 0, 0};
@@ -1294,10 +675,10 @@ public:
     }
     virtual MOS_STATUS AddFeatureGraphRTLog()
     {
-        MT_LOG5(MT_VP_FEATURE_GRAPH_SWFILTERDEINTERLACE, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SAMPLETYPEINPUT, m_Params.sampleTypeInput, MT_VP_FEATURE_GRAPH_FILTER_FMDKERNELENABLE, m_Params.bFmdKernelEnable,
-                MT_VP_FEATURE_GRAPH_FILTER_SINGLEFIELD, m_Params.diParams ? m_Params.diParams->bSingleField : -1, MT_VP_FEATURE_GRAPH_FILTER_DIMODE, m_Params.diParams ? m_Params.diParams->DIMode : -1,
-                MT_VP_FEATURE_GRAPH_FILTER_FEATURETYPE, GetFeatureType());
-        VP_PUBLIC_NORMALMESSAGE("Feature Graph: SwFilterDeinterlace: sampleTypeInput %d, bFmdKernelEnable %d, bSingleField %d, DIMode %d, FeatureType %d", m_Params.sampleTypeInput, m_Params.bFmdKernelEnable,
+        MT_LOG4(MT_VP_FEATURE_GRAPH_SWFILTERDEINTERLACE, MT_NORMAL, MT_VP_FEATURE_GRAPH_FILTER_SAMPLETYPEINPUT, m_Params.sampleTypeInput,
+                 MT_VP_FEATURE_GRAPH_FILTER_SINGLEFIELD, m_Params.diParams ? m_Params.diParams->bSingleField : -1, MT_VP_FEATURE_GRAPH_FILTER_DIMODE, m_Params.diParams ? m_Params.diParams->DIMode : -1,
+                 MT_VP_FEATURE_GRAPH_FILTER_FEATURETYPE, GetFeatureType());
+        VP_PUBLIC_NORMALMESSAGE("Feature Graph: SwFilterDeinterlace: sampleTypeInput %d, bSingleField %d, DIMode %d, FeatureType %d", m_Params.sampleTypeInput,
                                 m_Params.diParams ? m_Params.diParams->bSingleField : -1, m_Params.diParams ? m_Params.diParams->DIMode : -1, GetFeatureType());
         return MOS_STATUS_SUCCESS;
     }
@@ -1435,6 +816,7 @@ enum HDR_STAGE
     HDR_STAGE_3DLUT_KERNEL,
     HDR_STAGE_VEBOX_3DLUT_UPDATE,
     HDR_STAGE_VEBOX_3DLUT_NO_UPDATE,
+    HDR_STAGE_VEBOX_EXTERNAL_3DLUT,
 };
 
 //!
@@ -1488,6 +870,7 @@ struct FeatureParamHdr : public FeatureParam
     HDR_STAGE          stage                                                = HDR_STAGE_DEFAULT;
     uint32_t           widthInput                                           = 0;
     uint32_t           heightInput                                          = 0;
+    uint32_t           lutSize                                              = 0;
     VPHAL_HDR_LUT_MODE lutMode                                              = VPHAL_HDR_LUT_MODE_NONE; //!< LUT Mode
     VPHAL_HDR_LUT_MODE globalLutMode                                        = VPHAL_HDR_LUT_MODE_NONE; //!< Global LUT mode control for debugging purpose
     bool               bGpuGenerate3DLUT                                    = false;               //!< Flag for per frame GPU generation of 3DLUT
@@ -1497,9 +880,11 @@ struct FeatureParamHdr : public FeatureParam
     uint32_t                uiSplitFramePortions                 = 1;                     //!< Split Frame flag
     bool                    bForceSplitFrame                     = false;
     bool                    bNeed3DSampler                       = false;                 //!< indicate whether 3D should neede by force considering AVS removal etc.
+    bool                    isL0KernelEnabled                    = false;
 
     HDR_PARAMS srcHDRParams    = {};
     HDR_PARAMS targetHDRParams = {};
+    PVPHAL_3DLUT_PARAMS external3DLutParams = nullptr;
 };
 
 class SwFilterHdr : public SwFilter
