@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -72,7 +72,10 @@ public:
         uint8_t                       rtCacheSetting      = 0;                            //!< Render Target cache usage
 #if (_DEBUG || _RELEASE_INTERNAL)
         uint8_t                       rtOldCacheSetting   = 0;                            //!< Render Target old cache usage
+        bool                          isL03DLut           = false;
 #endif
+        bool                          VeboxScalability    = false;                        //!< Vebox Scalability flag
+        bool                          VPApogeios          = false;                        //!< VP Apogeios flag
     };
 
     virtual ~VpFeatureReport(){};
