@@ -219,6 +219,7 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
     if (m_vpPlatformInterface)
     {
         m_ctrlValDefault.eufusionBypassWaEnabled = m_vpPlatformInterface->IsEufusionBypassWaEnabled();
+        m_ctrlValDefault.decompForInterlacedSurfWaEnabled = m_vpPlatformInterface->IsDecompForInterlacedSurfWaEnabled();
     }
     else
     {
@@ -226,10 +227,12 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
         VP_PUBLIC_ASSERTMESSAGE("m_vpPlatformInterface == nullptr");
     }
     VP_PUBLIC_NORMALMESSAGE("eufusionBypassWaEnabled %d", m_ctrlValDefault.eufusionBypassWaEnabled);
+    VP_PUBLIC_NORMALMESSAGE("decompForInterlacedSurfWaEnabled %d", m_ctrlValDefault.decompForInterlacedSurfWaEnabled);
 
     MT_LOG3(MT_VP_USERFEATURE_CTRL, MT_NORMAL, MT_VP_UF_CTRL_DISABLE_VEOUT, m_ctrlValDefault.disableVeboxOutput,
         MT_VP_UF_CTRL_DISABLE_SFC, m_ctrlValDefault.disableSfc, MT_VP_UF_CTRL_CCS, m_ctrlValDefault.computeContextEnabled);
 
+#if (_DEBUG || _RELEASE_INTERNAL)
     uint32_t globalLutMode = VPHAL_HDR_LUT_MODE_NONE;
     status                 = ReadUserSetting(
         m_userSettingPtr,
@@ -268,6 +271,7 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
     {
         m_ctrlValDefault.disableAutoMode = disableAutoMode;
     }
+#endif
 
     uint32_t splitFramePortions = 1;
     status                      = ReadUserSetting(
@@ -282,11 +286,22 @@ VpUserFeatureControl::VpUserFeatureControl(MOS_INTERFACE &osInterface, VpPlatfor
         m_ctrlValDefault.splitFramePortions = splitFramePortions;
     }
 
+    //check vebox type 
+    if (skuTable && (MEDIA_IS_SKU(skuTable, FtrVeboxTypeH)))
+    {
+        m_ctrlValDefault.veboxTypeH = true;
+    }
+    VP_PUBLIC_NORMALMESSAGE("veboxTypeH %d", m_ctrlValDefault.veboxTypeH);
+
     m_ctrlVal = m_ctrlValDefault;
 }
 
 VpUserFeatureControl::~VpUserFeatureControl()
 {
+    if (m_pOcaFeatureControlInfo)
+    {
+        MOS_FreeMemAndSetNull(m_pOcaFeatureControlInfo);
+    }
 }
 
 MOS_STATUS VpUserFeatureControl::CreateUserSettingForDebug()
@@ -311,6 +326,22 @@ MOS_STATUS VpUserFeatureControl::CreateUserSettingForDebug()
 #endif
 
 #if (_DEBUG || _RELEASE_INTERNAL)
+    uint32_t   force3DLutInterpolation = 0;
+    eRegKeyReadStatus                  = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        force3DLutInterpolation,
+        __VPHAL_FORCE_3DLUT_INTERPOLATION,
+        MediaUserSetting::Group::Sequence);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.force3DLutInterpolation = force3DLutInterpolation;
+    }
+    else
+    {
+        // Default value
+        m_ctrlValDefault.force3DLutInterpolation = 0;
+    }
+
     //SFC NV12/P010 Linear Output.
     uint32_t enabledSFCNv12P010LinearOutput = 0;
     eRegKeyReadStatus = ReadUserSettingForDebug(
@@ -362,6 +393,22 @@ MOS_STATUS VpUserFeatureControl::CreateUserSettingForDebug()
         // Default value
         m_ctrlValDefault.enableIFNCC = false;
     }
+
+    bool bEnableL03DLut = false;
+    eRegKeyReadStatus   = ReadUserSettingForDebug(
+        m_userSettingPtr,
+        bEnableL03DLut,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_L0_3DLUT,
+        MediaUserSetting::Group::Sequence);
+    if (MOS_SUCCEEDED(eRegKeyReadStatus))
+    {
+        m_ctrlValDefault.bEnableL03DLut = bEnableL03DLut;
+    }
+    else
+    {
+        // Default value
+        m_ctrlValDefault.bEnableL03DLut = false;
+    }
 #endif
     return MOS_STATUS_SUCCESS;
 }
@@ -381,3 +428,12 @@ MOS_STATUS VpUserFeatureControl::Update(PVP_PIPELINE_PARAMS params)
 
     return MOS_STATUS_SUCCESS;
 }
+
+PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO VpUserFeatureControl::GetOcaFeautreControlInfo()
+{
+    if (nullptr == m_pOcaFeatureControlInfo)
+    {
+        m_pOcaFeatureControlInfo = (PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO)MOS_AllocAndZeroMemory(sizeof(MOS_OCA_LOG_USER_FEATURE_CONTROL_INFO));
+    }
+    return m_pOcaFeatureControlInfo;
+}
\ No newline at end of file
