@@ -51,21 +51,26 @@ public:
         bool disableDn                      = false;
         bool cscCosffPatchModeDisabled      = false;
         bool ForceEnableVeboxOutputSurf     = false;
+        bool veboxTypeH                     = false;
 
 #if (_DEBUG || _RELEASE_INTERNAL)
         bool forceDecompressedOutput        = false;
+        uint32_t force3DLutInterpolation    = 0;
         uint32_t enabledSFCNv12P010LinearOutput = 0;
         uint32_t enabledSFCRGBPRGB24Output  = 0;
         bool     enableIFNCC                    = false;
+        bool     bEnableL03DLut                 = false;
 #endif
         bool disablePacketReuse             = false;
         bool enablePacketReuseTeamsAlways   = false;
 
         VPHAL_HDR_LUT_MODE globalLutMode      = VPHAL_HDR_LUT_MODE_NONE;  //!< Global LUT mode control for debugging purpose
         bool               gpuGenerate3DLUT   = false;                        //!< Flag for per frame GPU generation of 3DLUT
+        bool               isExternal3DLutSupport  = true;
         bool               disableAutoMode    = false;
         bool               clearVideoViewMode = false;
         uint32_t           splitFramePortions = 1;
+        bool               decompForInterlacedSurfWaEnabled = false;
     };
 
 #if (_DEBUG || _RELEASE_INTERNAL)
@@ -74,6 +79,11 @@ public:
         return m_ctrlVal.forceDecompressedOutput;
     }
 
+    uint32_t Force3DLutInterpolation()
+    {
+        return m_ctrlVal.force3DLutInterpolation;
+    }
+
     uint32_t EnabledSFCNv12P010LinearOutput()
     {
         return m_ctrlVal.enabledSFCNv12P010LinearOutput;
@@ -84,9 +94,15 @@ public:
         return m_ctrlVal.enabledSFCRGBPRGB24Output;
     }
 
-    bool EnableIFNCC() {
+    bool EnableIFNCC() 
+    {
         return m_ctrlVal.enableIFNCC;
     }
+
+    bool EnableL03DLut()
+    {
+        return m_ctrlVal.bEnableL03DLut;
+    }
 #endif
 
     virtual MOS_STATUS CreateUserSettingForDebug();
@@ -148,6 +164,11 @@ public:
         return m_ctrlVal.gpuGenerate3DLUT;
     }
 
+    bool IsExternal3DLutSupport()
+    {
+        return m_ctrlVal.isExternal3DLutSupport;
+    }
+
     bool IsDisableAutoMode()
     {
         return m_ctrlVal.disableAutoMode;
@@ -158,6 +179,16 @@ public:
         return m_ctrlVal.clearVideoViewMode;
     }
 
+    bool IsDecompForInterlacedSurfWaEnabled()
+    {
+        return m_ctrlVal.decompForInterlacedSurfWaEnabled;
+    }
+
+    bool IsVeboxTypeHMode()
+    {
+        return m_ctrlVal.veboxTypeH;
+    }
+
     MOS_STATUS SetClearVideoViewMode(bool mode)
     {
         m_ctrlVal.clearVideoViewMode = mode;
@@ -179,6 +210,8 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    virtual PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO GetOcaFeautreControlInfo();
+
     const void *m_owner = nullptr; // The object who create current instance.
 
 protected:
@@ -188,6 +221,7 @@ protected:
     CONTROL_VALUES m_ctrlValDefault = {};
     CONTROL_VALUES m_ctrlVal        = {};
     MediaUserSettingSharedPtr m_userSettingPtr = nullptr;  //!< usersettingInstance
+    PMOS_OCA_LOG_USER_FEATURE_CONTROL_INFO m_pOcaFeatureControlInfo = nullptr;
 
     MEDIA_CLASS_DEFINE_END(vp__VpUserFeatureControl)
 };
