@@ -67,9 +67,11 @@ MOS_STATUS VpUtils::ReAllocateSurface(
         goto finish;
     }
 
-    if (osInterface->bOptimizeCpuTiming &&
-        (defaultResType == MOS_GFXRES_BUFFER) &&
-        (surface->dwWidth >= dwWidth))
+    // reuse the allocated buffer if the allocated size was larger than request size when OptimizeCpuTiming is enabled
+    if (osInterface->bOptimizeCpuTiming                             &&
+        !Mos_ResourceIsNull(&surface->OsResource)                   &&
+        (Format_Buffer                        == format)            &&
+        (surface->dwWidth * surface->dwHeight >= dwWidth * dwHeight))
     {
         goto finish;
     }
@@ -122,6 +124,13 @@ finish:
     return eStatus;
 }
 
+bool VpUtils::IsVerticalRotation(VPHAL_ROTATION rotation) {
+    return (rotation != VPHAL_ROTATION_IDENTITY &&
+            rotation != VPHAL_ROTATION_180 &&
+            rotation != VPHAL_MIRROR_VERTICAL &&
+            rotation != VPHAL_MIRROR_HORIZONTAL);
+}
+
 bool VpUtils::IsSyncFreeNeededForMMCSurface(PVPHAL_SURFACE surface, PMOS_INTERFACE osInterface)
 {
     if (nullptr == surface || nullptr == osInterface)
