@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -34,8 +34,7 @@
 #include "mos_os_virtualengine_next.h"
 #include "mos_interface.h"
 #include "mos_os_cp_interface_specific.h"
-#ifdef ENABLE_NEW_KMD
-// This header file is in close source temporarily. Could not find this header file in open source repo.
+#ifdef ENABLE_XE_KMD
 #include "mos_gpucontext_specific_next_xe.h"
 #endif
 
@@ -120,7 +119,7 @@ GpuContextNext *GpuContextSpecificNext::Create(
     {
         return MOS_New(GpuContextSpecificNext, gpuNode, cmdBufMgr, reusedContext);
     }
-#ifdef ENABLE_NEW_KMD
+#ifdef ENABLE_XE_KMD
     else if (DEVICE_TYPE_XE == type)
     {
         return MOS_New(GpuContextSpecificNextXe, gpuNode, cmdBufMgr, reusedContext);
@@ -542,6 +541,7 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
 
     MosUtilities::MosUnlockMutex(m_cmdBufPoolMutex);
 
+    m_ocaLogSectionSupported = osContext->m_ocaLogSectionSupported;
     if (m_ocaLogSectionSupported)
     {
         // increase size for oca log section
@@ -1988,53 +1988,32 @@ bool GpuContextSpecificNext::SelectEngineInstanceByUser(void *engine_map,
         uint32_t *engineNum, uint32_t userEngineInstance, MOS_GPU_NODE gpuNode)
 {
     uint32_t engineInstance     = 0x0;
-    struct i915_engine_class_instance *engineMap = (struct i915_engine_class_instance *)engine_map;
 
-    if(gpuNode == MOS_GPU_NODE_COMPUTE)
+    if (userEngineInstance && m_osParameters)
     {
-        engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_COMPUTE_INSTANCE_SHIFT)
-            & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
-    }
-    else if(gpuNode == MOS_GPU_NODE_VE)
-    {
-        engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_VEBOX_INSTANCE_SHIFT)
-            & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
-    }
-    else if(gpuNode == MOS_GPU_NODE_VIDEO || gpuNode == MOS_GPU_NODE_VIDEO2)
-    {
-        engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_VDBOX_INSTANCE_SHIFT)
-            & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
-    }
-    else
-    {
-        MOS_OS_NORMALMESSAGE("Invalid gpu node in use.");
-    }
-
-    if(engineInstance)
-    {
-        auto unSelectIndex = 0;
-        for(auto bit = 0; bit < *engineNum; bit++)
+        if(gpuNode == MOS_GPU_NODE_COMPUTE)
         {
-            if(((engineInstance >> bit) & 0x1) && (bit > unSelectIndex))
-            {
-                engineMap[unSelectIndex].engine_class = engineMap[bit].engine_class;
-                engineMap[unSelectIndex].engine_instance = engineMap[bit].engine_instance;
-                engineMap[bit].engine_class = 0;
-                engineMap[bit].engine_instance = 0;
-                unSelectIndex++;
-            }
-            else if(((engineInstance >> bit) & 0x1) && (bit == unSelectIndex))
-            {
-                unSelectIndex++;
-            }
-            else if(!((engineInstance >> bit) & 0x1))
-            {
-                engineMap[bit].engine_class = 0;
-                engineMap[bit].engine_instance = 0;
-            }
+            engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_COMPUTE_INSTANCE_SHIFT)
+                & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
         }
-        *engineNum = unSelectIndex;
+        else if(gpuNode == MOS_GPU_NODE_VE)
+        {
+            engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_VEBOX_INSTANCE_SHIFT)
+                & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
+        }
+        else if(gpuNode == MOS_GPU_NODE_VIDEO || gpuNode == MOS_GPU_NODE_VIDEO2)
+        {
+            engineInstance  = (userEngineInstance >> ENGINE_INSTANCE_SELECT_VDBOX_INSTANCE_SHIFT)
+                & (ENGINE_INSTANCE_SELECT_ENABLE_MASK >> (MAX_ENGINE_INSTANCE_NUM - *engineNum));
+        }
+        else
+        {
+            MOS_OS_NORMALMESSAGE("Invalid gpu node in use.");
+        }
+
+        mos_select_fixed_engine(m_osParameters->bufmgr, engine_map, engineNum, engineInstance);
     }
+
     return engineInstance;
 }
 #endif
