@@ -67,6 +67,8 @@ int32_t g_mosMemoryFailSimulateAllocCounter = 0;
 int32_t *MosUtilities::m_mosAllocMemoryFailSimulateAllocCounter = &g_mosMemoryFailSimulateAllocCounter;
 #endif
 
+static bool s_skipToReportReg = false;
+
 double MosUtilities::MosGetTime()
 {
     struct timespec ts = {};
@@ -1551,6 +1553,13 @@ MOS_STATUS MosUtilities::MosInitializeReg(RegBufferMap &regBufferMap)
         {
             std::string id       = "";
 
+            static const char *disableReportRegKeyList[] = {
+#if (_DEBUG || _RELEASE_INTERNAL)
+                __MEDIA_USER_FEATURE_VALUE_ENABLE_MEDIA_CCS,
+#endif
+                "INTEL MEDIA ALLOC MODE"
+            };
+            static const uint32_t disableReportRegKeyListCount = sizeof(disableReportRegKeyList) / sizeof(disableReportRegKeyList[0]);
             while(!regStream.eof())
             {
                 std::string line = "";
@@ -1585,8 +1594,22 @@ MOS_STATUS MosUtilities::MosInitializeReg(RegBufferMap &regBufferMap)
                     {
                         std::string name = line.substr(0,pos);
                         std::string value = line.substr(pos+1);
-                        auto        &keys  = regBufferMap[id];
-                        keys[name]       = value;
+                        if (name.size() > 0 && value.size() > 0)
+                        {
+                            auto &keys = regBufferMap[id];
+                            keys[name] = value;
+                            if (s_skipToReportReg == false && id == USER_SETTING_CONFIG_PATH)
+                            {
+                                for (uint32_t i = 0; i < disableReportRegKeyListCount; i++)
+                                {
+                                    if (strcmp(name.c_str(), disableReportRegKeyList[i]) == 0)
+                                    {
+                                        s_skipToReportReg = true;
+                                        break;
+                                    }
+                                }
+                            }
+                        }
                     }
                 }
             }
@@ -1606,6 +1629,12 @@ MOS_STATUS MosUtilities::MosInitializeReg(RegBufferMap &regBufferMap)
 MOS_STATUS MosUtilities::MosUninitializeReg(RegBufferMap &regBufferMap)
 {
     MOS_STATUS status = MOS_STATUS_SUCCESS;
+
+    if (s_skipToReportReg)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
     if (regBufferMap.size() == 0)
     {
         return MOS_STATUS_SUCCESS;
